# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtHttpServer, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtHttpServer`

import PySide6.QtHttpServer
import PySide6.QtCore
import PySide6.QtNetwork

import os
import enum
import typing
import collections.abc
from shiboken6 import Shiboken


class QAbstractHttpServer(PySide6.QtCore.QObject):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    @typing.overload
    def bind(self, server: PySide6.QtNetwork.QLocalServer, /) -> bool: ...
    @typing.overload
    def bind(self, server: PySide6.QtNetwork.QTcpServer, /) -> bool: ...
    def configuration(self, /) -> PySide6.QtHttpServer.QHttpServerConfiguration: ...
    def http2Configuration(self, /) -> PySide6.QtNetwork.QHttp2Configuration: ...
    def localServers(self, /) -> typing.List[PySide6.QtNetwork.QLocalServer]: ...
    def serverPorts(self, /) -> typing.List[int]: ...
    def servers(self, /) -> typing.List[PySide6.QtNetwork.QTcpServer]: ...
    def setConfiguration(self, config: PySide6.QtHttpServer.QHttpServerConfiguration, /) -> None: ...
    def setHttp2Configuration(self, configuration: PySide6.QtNetwork.QHttp2Configuration, /) -> None: ...


class QFutureHttpServerResponse(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QFutureHttpServerResponse: PySide6.QtHttpServer.QFutureHttpServerResponse, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def cancel(self, /) -> None: ...
    def cancelChain(self, /) -> None: ...
    def isCanceled(self, /) -> bool: ...
    def isFinished(self, /) -> bool: ...
    def isPaused(self, /) -> bool: ...
    def isRunning(self, /) -> bool: ...
    def isStarted(self, /) -> bool: ...
    def isSuspended(self, /) -> bool: ...
    def isSuspending(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def pause(self, /) -> None: ...
    def progressMaximum(self, /) -> int: ...
    def progressMinimum(self, /) -> int: ...
    def progressText(self, /) -> str: ...
    def progressValue(self, /) -> int: ...
    def resultCount(self, /) -> int: ...
    def resume(self, /) -> None: ...
    def setPaused(self, paused: bool, /) -> None: ...
    def setSuspended(self, suspend: bool, /) -> None: ...
    def suspend(self, /) -> None: ...
    def togglePaused(self, /) -> None: ...
    def toggleSuspended(self, /) -> None: ...
    def waitForFinished(self, /) -> None: ...


class QHttpServer(PySide6.QtHttpServer.QAbstractHttpServer):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def addAfterRequestHandler(self, context: PySide6.QtCore.QObject, callback: collections.abc.Callable[..., typing.Any], /) -> None: ...
    def clearMissingHandler(self, /) -> None: ...
    def handleRequest(self, request: PySide6.QtHttpServer.QHttpServerRequest, responder: PySide6.QtHttpServer.QHttpServerResponder, /) -> bool: ...
    def missingHandler(self, request: PySide6.QtHttpServer.QHttpServerRequest, responder: PySide6.QtHttpServer.QHttpServerResponder, /) -> None: ...
    def route(self, rule: str, callback: collections.abc.Callable[..., typing.Any], /) -> bool: ...
    def router(self, /) -> PySide6.QtHttpServer.QHttpServerRouter: ...


class QHttpServerConfiguration(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtHttpServer.QHttpServerConfiguration, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtHttpServer.QHttpServerConfiguration, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtHttpServer.QHttpServerConfiguration, /) -> bool: ...
    def keepAliveTimeout(self, /) -> int: ...
    def maximumBodySize(self, /) -> int: ...
    def maximumHeaderFieldCount(self, /) -> int: ...
    def maximumHeaderFieldSize(self, /) -> int: ...
    def maximumTotalHeaderSize(self, /) -> int: ...
    def maximumUrlSize(self, /) -> int: ...
    def rateLimitPerSecond(self, /) -> int: ...
    def setKeepAliveTimeout(self, timeout: int, /) -> None: ...
    def setMaximumBodySize(self, maxBodySize: int, /) -> None: ...
    def setMaximumHeaderFieldCount(self, maxNumberOfHeaders: int, /) -> None: ...
    def setMaximumHeaderFieldSize(self, maxSingleHeaderSize: int, /) -> None: ...
    def setMaximumTotalHeaderSize(self, maxTotalHeadersSize: int, /) -> None: ...
    def setMaximumUrlSize(self, maxUrlSize: int, /) -> None: ...
    def setRateLimitPerSecond(self, maxRequests: int, /) -> None: ...
    def swap(self, other: PySide6.QtHttpServer.QHttpServerConfiguration, /) -> None: ...


class QHttpServerRequest(Shiboken.Object):

    class Method(enum.Flag):

        Unknown                   = 0x0
        Get                       = 0x1
        Put                       = 0x2
        Delete                    = 0x4
        Post                      = 0x8
        Head                      = 0x10
        Options                   = 0x20
        Patch                     = 0x40
        Connect                   = 0x80
        Trace                     = 0x100
        AnyKnown                  = 0x1ff


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtHttpServer.QHttpServerRequest, /) -> None: ...

    def body(self, /) -> PySide6.QtCore.QByteArray: ...
    def headers(self, /) -> PySide6.QtNetwork.QHttpHeaders: ...
    def localAddress(self, /) -> PySide6.QtNetwork.QHostAddress: ...
    def localPort(self, /) -> int: ...
    def method(self, /) -> PySide6.QtHttpServer.QHttpServerRequest.Method: ...
    def query(self, /) -> PySide6.QtCore.QUrlQuery: ...
    def remoteAddress(self, /) -> PySide6.QtNetwork.QHostAddress: ...
    def remotePort(self, /) -> int: ...
    def sslConfiguration(self, /) -> PySide6.QtNetwork.QSslConfiguration: ...
    def swap(self, other: PySide6.QtHttpServer.QHttpServerRequest, /) -> None: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...
    def value(self, key: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> PySide6.QtCore.QByteArray: ...


class QHttpServerResponder(Shiboken.Object):

    class StatusCode(enum.Enum):

        Continue                  = 0x64
        SwitchingProtocols        = 0x65
        Processing                = 0x66
        Ok                        = 0xc8
        Created                   = 0xc9
        Accepted                  = 0xca
        NonAuthoritativeInformation = 0xcb
        NoContent                 = 0xcc
        ResetContent              = 0xcd
        PartialContent            = 0xce
        MultiStatus               = 0xcf
        AlreadyReported           = 0xd0
        IMUsed                    = 0xe2
        MultipleChoices           = 0x12c
        MovedPermanently          = 0x12d
        Found                     = 0x12e
        SeeOther                  = 0x12f
        NotModified               = 0x130
        UseProxy                  = 0x131
        TemporaryRedirect         = 0x133
        PermanentRedirect         = 0x134
        BadRequest                = 0x190
        Unauthorized              = 0x191
        PaymentRequired           = 0x192
        Forbidden                 = 0x193
        NotFound                  = 0x194
        MethodNotAllowed          = 0x195
        NotAcceptable             = 0x196
        ProxyAuthenticationRequired = 0x197
        RequestTimeout            = 0x198
        Conflict                  = 0x199
        Gone                      = 0x19a
        LengthRequired            = 0x19b
        PreconditionFailed        = 0x19c
        PayloadTooLarge           = 0x19d
        UriTooLong                = 0x19e
        UnsupportedMediaType      = 0x19f
        RequestRangeNotSatisfiable = 0x1a0
        ExpectationFailed         = 0x1a1
        ImATeapot                 = 0x1a2
        MisdirectedRequest        = 0x1a5
        UnprocessableEntity       = 0x1a6
        Locked                    = 0x1a7
        FailedDependency          = 0x1a8
        UpgradeRequired           = 0x1aa
        PreconditionRequired      = 0x1ac
        TooManyRequests           = 0x1ad
        RequestHeaderFieldsTooLarge = 0x1af
        UnavailableForLegalReasons = 0x1c3
        InternalServerError       = 0x1f4
        NotImplemented            = 0x1f5
        BadGateway                = 0x1f6
        ServiceUnavailable        = 0x1f7
        GatewayTimeout            = 0x1f8
        HttpVersionNotSupported   = 0x1f9
        VariantAlsoNegotiates     = 0x1fa
        InsufficientStorage       = 0x1fb
        LoopDetected              = 0x1fc
        NotExtended               = 0x1fe
        NetworkAuthenticationRequired = 0x1ff
        NetworkConnectTimeoutError = 0x257


    def isResponseCanceled(self, /) -> bool: ...
    def sendResponse(self, response: PySide6.QtHttpServer.QHttpServerResponse, /) -> None: ...
    def swap(self, other: PySide6.QtHttpServer.QHttpServerResponder, /) -> None: ...
    @typing.overload
    def write(self, data: PySide6.QtCore.QIODevice, headers: PySide6.QtNetwork.QHttpHeaders, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def write(self, data: PySide6.QtCore.QIODevice, mimeType: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def write(self, headers: PySide6.QtNetwork.QHttpHeaders, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def write(self, document: PySide6.QtCore.QJsonDocument, headers: PySide6.QtNetwork.QHttpHeaders, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def write(self, document: PySide6.QtCore.QJsonDocument, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def write(self, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def write(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, headers: PySide6.QtNetwork.QHttpHeaders, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def write(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, mimeType: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def writeBeginChunked(self, headers: PySide6.QtNetwork.QHttpHeaders, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def writeBeginChunked(self, headers: PySide6.QtNetwork.QHttpHeaders, trailerNames: collections.abc.Sequence[PySide6.QtNetwork.QHttpHeaders.WellKnownHeader], /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def writeBeginChunked(self, mimeType: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    def writeChunk(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    def writeEndChunked(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    def writeEndChunked(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, trailers: PySide6.QtNetwork.QHttpHeaders, /) -> None: ...


class QHttpServerResponse(Shiboken.Object):

    @typing.overload
    def __init__(self, data: PySide6.QtCore.QJsonArray, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def __init__(self, statusCode: PySide6.QtHttpServer.QHttpServerResponder.StatusCode, /) -> None: ...
    @typing.overload
    def __init__(self, data: str, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def __init__(self, data: typing.Dict[str, PySide6.QtCore.QJsonValue], /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def __init__(self, data: bytes | bytearray | memoryview, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def __init__(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...
    @typing.overload
    def __init__(self, mimeType: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /, status: PySide6.QtHttpServer.QHttpServerResponder.StatusCode = ...) -> None: ...

    def data(self, /) -> PySide6.QtCore.QByteArray: ...
    @staticmethod
    def fromFile(fileName: str, /) -> PySide6.QtHttpServer.QHttpServerResponse: ...
    def headers(self, /) -> PySide6.QtNetwork.QHttpHeaders: ...
    def mimeType(self, /) -> PySide6.QtCore.QByteArray: ...
    def setHeaders(self, newHeaders: PySide6.QtNetwork.QHttpHeaders, /) -> None: ...
    def statusCode(self, /) -> PySide6.QtHttpServer.QHttpServerResponder.StatusCode: ...
    def swap(self, other: PySide6.QtHttpServer.QHttpServerResponse, /) -> None: ...


class QHttpServerRouter(Shiboken.Object):

    def __init__(self, server: PySide6.QtHttpServer.QAbstractHttpServer, /) -> None: ...

    def addConverter(self, metaType: PySide6.QtCore.QMetaType | PySide6.QtCore.QMetaType.Type, regexp: str, /) -> None: ...
    def clearConverters(self, /) -> None: ...
    def converters(self, /) -> typing.Dict[PySide6.QtCore.QMetaType, str]: ...
    def handleRequest(self, request: PySide6.QtHttpServer.QHttpServerRequest, responder: PySide6.QtHttpServer.QHttpServerResponder, /) -> bool: ...
    def removeConverter(self, metaType: PySide6.QtCore.QMetaType | PySide6.QtCore.QMetaType.Type, /) -> None: ...


class QHttpServerRouterRule(Shiboken.Object):
    def contextObject(self, /) -> PySide6.QtCore.QObject: ...
    def exec(self, request: PySide6.QtHttpServer.QHttpServerRequest, responder: PySide6.QtHttpServer.QHttpServerResponder, /) -> bool: ...
    def hasValidMethods(self, /) -> bool: ...
    def matches(self, request: PySide6.QtHttpServer.QHttpServerRequest, match: PySide6.QtCore.QRegularExpressionMatch, /) -> bool: ...


class QHttpServerWebSocketUpgradeResponse(Shiboken.Object):

    class ResponseType(enum.Enum):

        Accept                    = 0x0
        Deny                      = 0x1
        PassToNext                = 0x2


    def __init__(self, other: PySide6.QtHttpServer.QHttpServerWebSocketUpgradeResponse, /) -> None: ...

    @staticmethod
    def accept() -> PySide6.QtHttpServer.QHttpServerWebSocketUpgradeResponse: ...
    @typing.overload
    @staticmethod
    def deny() -> PySide6.QtHttpServer.QHttpServerWebSocketUpgradeResponse: ...
    @typing.overload
    @staticmethod
    def deny(status: int, message: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> PySide6.QtHttpServer.QHttpServerWebSocketUpgradeResponse: ...
    def denyMessage(self, /) -> PySide6.QtCore.QByteArray: ...
    def denyStatus(self, /) -> int: ...
    @staticmethod
    def passToNext() -> PySide6.QtHttpServer.QHttpServerWebSocketUpgradeResponse: ...
    def swap(self, other: PySide6.QtHttpServer.QHttpServerWebSocketUpgradeResponse, /) -> None: ...
    def type(self, /) -> PySide6.QtHttpServer.QHttpServerWebSocketUpgradeResponse.ResponseType: ...


class QIntList: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtPdfWidgets, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtPdfWidgets`

import PySide6.QtPdfWidgets
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtWidgets
import PySide6.QtPdf

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal


class QIntList: ...


class QPdfPageSelector(PySide6.QtWidgets.QWidget):

    currentPageChanged       : typing.ClassVar[Signal] = ... # currentPageChanged(int)
    currentPageLabelChanged  : typing.ClassVar[Signal] = ... # currentPageLabelChanged(QString)
    documentChanged          : typing.ClassVar[Signal] = ... # documentChanged(QPdfDocument*)

    @typing.overload
    def __init__(self, parent: PySide6.QtWidgets.QWidget, /, *, document: PySide6.QtPdf.QPdfDocument | None = ..., currentPage: int | None = ..., currentPageLabel: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, document: PySide6.QtPdf.QPdfDocument | None = ..., currentPage: int | None = ..., currentPageLabel: str | None = ...) -> None: ...

    def currentPage(self, /) -> int: ...
    def currentPageLabel(self, /) -> str: ...
    def document(self, /) -> PySide6.QtPdf.QPdfDocument: ...
    def setCurrentPage(self, index: int, /) -> None: ...
    def setDocument(self, document: PySide6.QtPdf.QPdfDocument, /) -> None: ...


class QPdfView(PySide6.QtWidgets.QAbstractScrollArea):

    currentSearchResultIndexChanged: typing.ClassVar[Signal] = ... # currentSearchResultIndexChanged(int)
    documentChanged          : typing.ClassVar[Signal] = ... # documentChanged(QPdfDocument*)
    documentMarginsChanged   : typing.ClassVar[Signal] = ... # documentMarginsChanged(QMargins)
    pageModeChanged          : typing.ClassVar[Signal] = ... # pageModeChanged(QPdfView::PageMode)
    pageSpacingChanged       : typing.ClassVar[Signal] = ... # pageSpacingChanged(int)
    searchModelChanged       : typing.ClassVar[Signal] = ... # searchModelChanged(QPdfSearchModel*)
    zoomFactorChanged        : typing.ClassVar[Signal] = ... # zoomFactorChanged(double)
    zoomModeChanged          : typing.ClassVar[Signal] = ... # zoomModeChanged(QPdfView::ZoomMode)

    class PageMode(enum.Enum):

        SinglePage                = 0x0
        MultiPage                 = 0x1

    class ZoomMode(enum.Enum):

        Custom                    = 0x0
        FitToWidth                = 0x1
        FitInView                 = 0x2


    @typing.overload
    def __init__(self, parent: PySide6.QtWidgets.QWidget, /, *, document: PySide6.QtPdf.QPdfDocument | None = ..., pageMode: PySide6.QtPdfWidgets.QPdfView.PageMode | None = ..., zoomMode: PySide6.QtPdfWidgets.QPdfView.ZoomMode | None = ..., zoomFactor: float | None = ..., pageSpacing: int | None = ..., documentMargins: PySide6.QtCore.QMargins | None = ..., searchModel: PySide6.QtPdf.QPdfSearchModel | None = ..., currentSearchResultIndex: int | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, document: PySide6.QtPdf.QPdfDocument | None = ..., pageMode: PySide6.QtPdfWidgets.QPdfView.PageMode | None = ..., zoomMode: PySide6.QtPdfWidgets.QPdfView.ZoomMode | None = ..., zoomFactor: float | None = ..., pageSpacing: int | None = ..., documentMargins: PySide6.QtCore.QMargins | None = ..., searchModel: PySide6.QtPdf.QPdfSearchModel | None = ..., currentSearchResultIndex: int | None = ...) -> None: ...

    def currentSearchResultIndex(self, /) -> int: ...
    def document(self, /) -> PySide6.QtPdf.QPdfDocument: ...
    def documentMargins(self, /) -> PySide6.QtCore.QMargins: ...
    def mouseMoveEvent(self, event: PySide6.QtGui.QMouseEvent, /) -> None: ...
    def mousePressEvent(self, event: PySide6.QtGui.QMouseEvent, /) -> None: ...
    def mouseReleaseEvent(self, event: PySide6.QtGui.QMouseEvent, /) -> None: ...
    def pageMode(self, /) -> PySide6.QtPdfWidgets.QPdfView.PageMode: ...
    def pageNavigator(self, /) -> PySide6.QtPdf.QPdfPageNavigator: ...
    def pageSpacing(self, /) -> int: ...
    def paintEvent(self, event: PySide6.QtGui.QPaintEvent, /) -> None: ...
    def resizeEvent(self, event: PySide6.QtGui.QResizeEvent, /) -> None: ...
    def scrollContentsBy(self, dx: int, dy: int, /) -> None: ...
    def searchModel(self, /) -> PySide6.QtPdf.QPdfSearchModel: ...
    def setCurrentSearchResultIndex(self, currentResult: int, /) -> None: ...
    def setDocument(self, document: PySide6.QtPdf.QPdfDocument, /) -> None: ...
    def setDocumentMargins(self, margins: PySide6.QtCore.QMargins, /) -> None: ...
    def setPageMode(self, mode: PySide6.QtPdfWidgets.QPdfView.PageMode, /) -> None: ...
    def setPageSpacing(self, spacing: int, /) -> None: ...
    def setSearchModel(self, searchModel: PySide6.QtPdf.QPdfSearchModel, /) -> None: ...
    def setZoomFactor(self, factor: float, /) -> None: ...
    def setZoomMode(self, mode: PySide6.QtPdfWidgets.QPdfView.ZoomMode, /) -> None: ...
    def zoomFactor(self, /) -> float: ...
    def zoomMode(self, /) -> PySide6.QtPdfWidgets.QPdfView.ZoomMode: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtDesigner, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtDesigner`

import PySide6.QtDesigner
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtWidgets

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QAbstractExtensionFactory(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def extension(self, object: PySide6.QtCore.QObject, iid: str, /) -> PySide6.QtCore.QObject: ...


class QAbstractExtensionManager(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def extension(self, object: PySide6.QtCore.QObject, iid: str, /) -> PySide6.QtCore.QObject: ...
    def registerExtensions(self, factory: PySide6.QtDesigner.QAbstractExtensionFactory, iid: str, /) -> None: ...
    def unregisterExtensions(self, factory: PySide6.QtDesigner.QAbstractExtensionFactory, iid: str, /) -> None: ...


class QAbstractFormBuilder(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def addMenuAction(self, action: PySide6.QtGui.QAction, /) -> None: ...
    def applyPropertyInternally(self, o: PySide6.QtCore.QObject, propertyName: str, value: typing.Any, /) -> bool: ...
    def checkProperty(self, obj: PySide6.QtCore.QObject, prop: str, /) -> bool: ...
    def createAction(self, parent: PySide6.QtCore.QObject, name: str, /) -> PySide6.QtGui.QAction: ...
    def createActionGroup(self, parent: PySide6.QtCore.QObject, name: str, /) -> PySide6.QtGui.QActionGroup: ...
    def createLayout(self, layoutName: str, parent: PySide6.QtCore.QObject, name: str, /) -> PySide6.QtWidgets.QLayout: ...
    def createWidget(self, widgetName: str, parentWidget: PySide6.QtWidgets.QWidget, name: str, /) -> PySide6.QtWidgets.QWidget: ...
    def errorString(self, /) -> str: ...
    def load(self, dev: PySide6.QtCore.QIODevice, /, parentWidget: PySide6.QtWidgets.QWidget | None = ...) -> PySide6.QtWidgets.QWidget: ...
    def reset(self, /) -> None: ...
    def save(self, dev: PySide6.QtCore.QIODevice, widget: PySide6.QtWidgets.QWidget, /) -> None: ...
    def setWorkingDirectory(self, directory: PySide6.QtCore.QDir, /) -> None: ...
    @staticmethod
    def toolBarAreaMetaEnum() -> PySide6.QtCore.QMetaEnum: ...
    def workingDirectory(self, /) -> PySide6.QtCore.QDir: ...


class QDesignerActionEditorInterface(PySide6.QtWidgets.QWidget):

    def __init__(self, parent: PySide6.QtWidgets.QWidget, /, flags: PySide6.QtCore.Qt.WindowType = ...) -> None: ...

    def core(self, /) -> PySide6.QtDesigner.QDesignerFormEditorInterface: ...
    def manageAction(self, action: PySide6.QtGui.QAction, /) -> None: ...
    def setFormWindow(self, formWindow: PySide6.QtDesigner.QDesignerFormWindowInterface, /) -> None: ...
    def unmanageAction(self, action: PySide6.QtGui.QAction, /) -> None: ...


class QDesignerContainerExtension(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def addWidget(self, widget: PySide6.QtWidgets.QWidget, /) -> None: ...
    def canAddWidget(self, /) -> bool: ...
    def canRemove(self, index: int, /) -> bool: ...
    def count(self, /) -> int: ...
    def currentIndex(self, /) -> int: ...
    def insertWidget(self, index: int, widget: PySide6.QtWidgets.QWidget, /) -> None: ...
    def remove(self, index: int, /) -> None: ...
    def setCurrentIndex(self, index: int, /) -> None: ...
    def widget(self, index: int, /) -> PySide6.QtWidgets.QWidget: ...


class QDesignerCustomWidgetCollectionInterface(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def customWidgets(self, /) -> typing.List[PySide6.QtDesigner.QDesignerCustomWidgetInterface]: ...


class QDesignerCustomWidgetInterface(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def codeTemplate(self, /) -> str: ...
    def createWidget(self, parent: PySide6.QtWidgets.QWidget, /) -> PySide6.QtWidgets.QWidget: ...
    def domXml(self, /) -> str: ...
    def group(self, /) -> str: ...
    def icon(self, /) -> PySide6.QtGui.QIcon: ...
    def includeFile(self, /) -> str: ...
    def initialize(self, core: PySide6.QtDesigner.QDesignerFormEditorInterface, /) -> None: ...
    def isContainer(self, /) -> bool: ...
    def isInitialized(self, /) -> bool: ...
    def name(self, /) -> str: ...
    def toolTip(self, /) -> str: ...
    def whatsThis(self, /) -> str: ...


class QDesignerDnDItemInterface(Shiboken.Object):

    class DropType(enum.Enum):

        MoveDrop                  = 0x0
        CopyDrop                  = 0x1


    def __init__(self, /) -> None: ...

    def decoration(self, /) -> PySide6.QtWidgets.QWidget: ...
    def hotSpot(self, /) -> PySide6.QtCore.QPoint: ...
    def source(self, /) -> PySide6.QtWidgets.QWidget: ...
    def type(self, /) -> PySide6.QtDesigner.QDesignerDnDItemInterface.DropType: ...
    def widget(self, /) -> PySide6.QtWidgets.QWidget: ...


class QDesignerDynamicPropertySheetExtension(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def addDynamicProperty(self, propertyName: str, value: typing.Any, /) -> int: ...
    def canAddDynamicProperty(self, propertyName: str, /) -> bool: ...
    def dynamicPropertiesAllowed(self, /) -> bool: ...
    def isDynamicProperty(self, index: int, /) -> bool: ...
    def removeDynamicProperty(self, index: int, /) -> bool: ...


class QDesignerFormEditorInterface(PySide6.QtCore.QObject):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def actionEditor(self, /) -> PySide6.QtDesigner.QDesignerActionEditorInterface: ...
    @staticmethod
    def createIcon(name: str, /) -> PySide6.QtGui.QIcon: ...
    def extensionManager(self, /) -> PySide6.QtDesigner.QExtensionManager: ...
    def formWindowManager(self, /) -> PySide6.QtDesigner.QDesignerFormWindowManagerInterface: ...
    def objectInspector(self, /) -> PySide6.QtDesigner.QDesignerObjectInspectorInterface: ...
    def pluginInstances(self, /) -> typing.List[PySide6.QtCore.QObject]: ...
    def propertyEditor(self, /) -> PySide6.QtDesigner.QDesignerPropertyEditorInterface: ...
    def resourceLocation(self, /) -> str: ...
    def setActionEditor(self, actionEditor: PySide6.QtDesigner.QDesignerActionEditorInterface, /) -> None: ...
    def setExtensionManager(self, extensionManager: PySide6.QtDesigner.QExtensionManager, /) -> None: ...
    def setFormManager(self, formWindowManager: PySide6.QtDesigner.QDesignerFormWindowManagerInterface, /) -> None: ...
    def setObjectInspector(self, objectInspector: PySide6.QtDesigner.QDesignerObjectInspectorInterface, /) -> None: ...
    def setPropertyEditor(self, propertyEditor: PySide6.QtDesigner.QDesignerPropertyEditorInterface, /) -> None: ...
    def setTopLevel(self, topLevel: PySide6.QtWidgets.QWidget, /) -> None: ...
    def setWidgetBox(self, widgetBox: PySide6.QtDesigner.QDesignerWidgetBoxInterface, /) -> None: ...
    def topLevel(self, /) -> PySide6.QtWidgets.QWidget: ...
    def widgetBox(self, /) -> PySide6.QtDesigner.QDesignerWidgetBoxInterface: ...


class QDesignerFormWindowCursorInterface(Shiboken.Object):

    class MoveMode(enum.Enum):

        MoveAnchor                = 0x0
        KeepAnchor                = 0x1

    class MoveOperation(enum.Enum):

        NoMove                    = 0x0
        Start                     = 0x1
        End                       = 0x2
        Next                      = 0x3
        Prev                      = 0x4
        Left                      = 0x5
        Right                     = 0x6
        Up                        = 0x7
        Down                      = 0x8


    def __init__(self, /) -> None: ...

    def current(self, /) -> PySide6.QtWidgets.QWidget: ...
    def formWindow(self, /) -> PySide6.QtDesigner.QDesignerFormWindowInterface: ...
    def hasSelection(self, /) -> bool: ...
    def isWidgetSelected(self, widget: PySide6.QtWidgets.QWidget, /) -> bool: ...
    def movePosition(self, op: PySide6.QtDesigner.QDesignerFormWindowCursorInterface.MoveOperation, /, mode: PySide6.QtDesigner.QDesignerFormWindowCursorInterface.MoveMode = ...) -> bool: ...
    def position(self, /) -> int: ...
    def resetWidgetProperty(self, widget: PySide6.QtWidgets.QWidget, name: str, /) -> None: ...
    def selectedWidget(self, index: int, /) -> PySide6.QtWidgets.QWidget: ...
    def selectedWidgetCount(self, /) -> int: ...
    def setPosition(self, pos: int, /, mode: PySide6.QtDesigner.QDesignerFormWindowCursorInterface.MoveMode = ...) -> None: ...
    def setProperty(self, name: str, value: typing.Any, /) -> None: ...
    def setWidgetProperty(self, widget: PySide6.QtWidgets.QWidget, name: str, value: typing.Any, /) -> None: ...
    def widget(self, index: int, /) -> PySide6.QtWidgets.QWidget: ...
    def widgetCount(self, /) -> int: ...


class QDesignerFormWindowInterface(PySide6.QtWidgets.QWidget):

    aboutToUnmanageWidget    : typing.ClassVar[Signal] = ... # aboutToUnmanageWidget(QWidget*)
    activated                : typing.ClassVar[Signal] = ... # activated(QWidget*)
    changed                  : typing.ClassVar[Signal] = ... # changed()
    featureChanged           : typing.ClassVar[Signal] = ... # featureChanged(Feature)
    fileNameChanged          : typing.ClassVar[Signal] = ... # fileNameChanged(QString)
    geometryChanged          : typing.ClassVar[Signal] = ... # geometryChanged()
    mainContainerChanged     : typing.ClassVar[Signal] = ... # mainContainerChanged(QWidget*)
    objectRemoved            : typing.ClassVar[Signal] = ... # objectRemoved(QObject*)
    resourceFilesChanged     : typing.ClassVar[Signal] = ... # resourceFilesChanged()
    selectionChanged         : typing.ClassVar[Signal] = ... # selectionChanged()
    toolChanged              : typing.ClassVar[Signal] = ... # toolChanged(int)
    widgetManaged            : typing.ClassVar[Signal] = ... # widgetManaged(QWidget*)
    widgetRemoved            : typing.ClassVar[Signal] = ... # widgetRemoved(QWidget*)
    widgetUnmanaged          : typing.ClassVar[Signal] = ... # widgetUnmanaged(QWidget*)

    class FeatureFlag(enum.Flag):

        EditFeature               = 0x1
        GridFeature               = 0x2
        DefaultFeature            = 0x3
        TabOrderFeature           = 0x4

    class ResourceFileSaveMode(enum.Enum):

        SaveAllResourceFiles      = 0x0
        SaveOnlyUsedResourceFiles = 0x1
        DontSaveResourceFiles     = 0x2


    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ..., flags: PySide6.QtCore.Qt.WindowType = ...) -> None: ...

    def absoluteDir(self, /) -> PySide6.QtCore.QDir: ...
    def activateResourceFilePaths(self, paths: collections.abc.Sequence[str], /) -> typing.Tuple[int, str]: ...
    def activeResourceFilePaths(self, /) -> typing.List[str]: ...
    def addResourceFile(self, path: str, /) -> None: ...
    def author(self, /) -> str: ...
    def beginCommand(self, description: str, /) -> None: ...
    def checkContents(self, /) -> typing.List[str]: ...
    def clearSelection(self, /, changePropertyDisplay: bool = ...) -> None: ...
    def commandHistory(self, /) -> PySide6.QtGui.QUndoStack: ...
    def comment(self, /) -> str: ...
    def contents(self, /) -> str: ...
    def core(self, /) -> PySide6.QtDesigner.QDesignerFormEditorInterface: ...
    def currentTool(self, /) -> int: ...
    def cursor(self, /) -> PySide6.QtDesigner.QDesignerFormWindowCursorInterface: ...
    def editWidgets(self, /) -> None: ...
    def emitSelectionChanged(self, /) -> None: ...
    def endCommand(self, /) -> None: ...
    def ensureUniqueObjectName(self, object: PySide6.QtCore.QObject, /) -> None: ...
    def exportMacro(self, /) -> str: ...
    def features(self, /) -> PySide6.QtDesigner.QDesignerFormWindowInterface.FeatureFlag: ...
    def fileName(self, /) -> str: ...
    @typing.overload
    @staticmethod
    def findFormWindow(w: PySide6.QtWidgets.QWidget, /) -> PySide6.QtDesigner.QDesignerFormWindowInterface: ...
    @typing.overload
    @staticmethod
    def findFormWindow(obj: PySide6.QtCore.QObject, /) -> PySide6.QtDesigner.QDesignerFormWindowInterface: ...
    def formContainer(self, /) -> PySide6.QtWidgets.QWidget: ...
    def grid(self, /) -> PySide6.QtCore.QPoint: ...
    def hasFeature(self, f: PySide6.QtDesigner.QDesignerFormWindowInterface.FeatureFlag, /) -> bool: ...
    def includeHints(self, /) -> typing.List[str]: ...
    def isDirty(self, /) -> bool: ...
    def isManaged(self, widget: PySide6.QtWidgets.QWidget, /) -> bool: ...
    def layoutDefault(self, /) -> typing.Tuple[int, int]: ...
    def layoutFunction(self, /) -> typing.Tuple[str, str]: ...
    def mainContainer(self, /) -> PySide6.QtWidgets.QWidget: ...
    def manageWidget(self, widget: PySide6.QtWidgets.QWidget, /) -> None: ...
    def pixmapFunction(self, /) -> str: ...
    def registerTool(self, tool: PySide6.QtDesigner.QDesignerFormWindowToolInterface, /) -> None: ...
    def removeResourceFile(self, path: str, /) -> None: ...
    def resourceFileSaveMode(self, /) -> PySide6.QtDesigner.QDesignerFormWindowInterface.ResourceFileSaveMode: ...
    def resourceFiles(self, /) -> typing.List[str]: ...
    def selectWidget(self, w: PySide6.QtWidgets.QWidget, /, select: bool = ...) -> None: ...
    def setAuthor(self, author: str, /) -> None: ...
    def setComment(self, comment: str, /) -> None: ...
    @typing.overload
    def setContents(self, dev: PySide6.QtCore.QIODevice, /) -> typing.Tuple[bool, str]: ...
    @typing.overload
    def setContents(self, contents: str, /) -> bool: ...
    def setCurrentTool(self, index: int, /) -> None: ...
    def setDirty(self, dirty: bool, /) -> None: ...
    def setExportMacro(self, exportMacro: str, /) -> None: ...
    def setFeatures(self, f: PySide6.QtDesigner.QDesignerFormWindowInterface.FeatureFlag, /) -> None: ...
    def setFileName(self, fileName: str, /) -> None: ...
    def setGrid(self, grid: PySide6.QtCore.QPoint, /) -> None: ...
    def setIncludeHints(self, includeHints: collections.abc.Sequence[str], /) -> None: ...
    def setLayoutDefault(self, margin: int, spacing: int, /) -> None: ...
    def setLayoutFunction(self, margin: str, spacing: str, /) -> None: ...
    def setMainContainer(self, mainContainer: PySide6.QtWidgets.QWidget, /) -> None: ...
    def setPixmapFunction(self, pixmapFunction: str, /) -> None: ...
    def setResourceFileSaveMode(self, behaviour: PySide6.QtDesigner.QDesignerFormWindowInterface.ResourceFileSaveMode, /) -> None: ...
    def simplifySelection(self, widgets: collections.abc.Sequence[PySide6.QtWidgets.QWidget], /) -> None: ...
    def tool(self, index: int, /) -> PySide6.QtDesigner.QDesignerFormWindowToolInterface: ...
    def toolCount(self, /) -> int: ...
    def unmanageWidget(self, widget: PySide6.QtWidgets.QWidget, /) -> None: ...


class QDesignerFormWindowManagerInterface(PySide6.QtCore.QObject):

    activeFormWindowChanged  : typing.ClassVar[Signal] = ... # activeFormWindowChanged(QDesignerFormWindowInterface*)
    formWindowAdded          : typing.ClassVar[Signal] = ... # formWindowAdded(QDesignerFormWindowInterface*)
    formWindowRemoved        : typing.ClassVar[Signal] = ... # formWindowRemoved(QDesignerFormWindowInterface*)
    formWindowSettingsChanged: typing.ClassVar[Signal] = ... # formWindowSettingsChanged(QDesignerFormWindowInterface*)

    class Action(enum.Enum):

        CutAction                 = 0x64
        CopyAction                = 0x65
        PasteAction               = 0x66
        DeleteAction              = 0x67
        SelectAllAction           = 0x68
        LowerAction               = 0xc8
        RaiseAction               = 0xc9
        UndoAction                = 0x12c
        RedoAction                = 0x12d
        HorizontalLayoutAction    = 0x190
        VerticalLayoutAction      = 0x191
        SplitHorizontalAction     = 0x192
        SplitVerticalAction       = 0x193
        GridLayoutAction          = 0x194
        FormLayoutAction          = 0x195
        BreakLayoutAction         = 0x196
        AdjustSizeAction          = 0x197
        SimplifyLayoutAction      = 0x198
        DefaultPreviewAction      = 0x1f4
        FormWindowSettingsDialogAction = 0x258

    class ActionGroup(enum.Enum):

        StyledPreviewActionGroup  = 0x64


    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def action(self, action: PySide6.QtDesigner.QDesignerFormWindowManagerInterface.Action, /) -> PySide6.QtGui.QAction: ...
    def actionAdjustSize(self, /) -> PySide6.QtGui.QAction: ...
    def actionBreakLayout(self, /) -> PySide6.QtGui.QAction: ...
    def actionCopy(self, /) -> PySide6.QtGui.QAction: ...
    def actionCut(self, /) -> PySide6.QtGui.QAction: ...
    def actionDelete(self, /) -> PySide6.QtGui.QAction: ...
    def actionFormLayout(self, /) -> PySide6.QtGui.QAction: ...
    def actionGridLayout(self, /) -> PySide6.QtGui.QAction: ...
    def actionGroup(self, actionGroup: PySide6.QtDesigner.QDesignerFormWindowManagerInterface.ActionGroup, /) -> PySide6.QtGui.QActionGroup: ...
    def actionHorizontalLayout(self, /) -> PySide6.QtGui.QAction: ...
    def actionLower(self, /) -> PySide6.QtGui.QAction: ...
    def actionPaste(self, /) -> PySide6.QtGui.QAction: ...
    def actionRaise(self, /) -> PySide6.QtGui.QAction: ...
    def actionRedo(self, /) -> PySide6.QtGui.QAction: ...
    def actionSelectAll(self, /) -> PySide6.QtGui.QAction: ...
    def actionSimplifyLayout(self, /) -> PySide6.QtGui.QAction: ...
    def actionSplitHorizontal(self, /) -> PySide6.QtGui.QAction: ...
    def actionSplitVertical(self, /) -> PySide6.QtGui.QAction: ...
    def actionUndo(self, /) -> PySide6.QtGui.QAction: ...
    def actionVerticalLayout(self, /) -> PySide6.QtGui.QAction: ...
    def activeFormWindow(self, /) -> PySide6.QtDesigner.QDesignerFormWindowInterface: ...
    def addFormWindow(self, formWindow: PySide6.QtDesigner.QDesignerFormWindowInterface, /) -> None: ...
    def closeAllPreviews(self, /) -> None: ...
    def core(self, /) -> PySide6.QtDesigner.QDesignerFormEditorInterface: ...
    def createFormWindow(self, /, parentWidget: PySide6.QtWidgets.QWidget | None = ..., flags: PySide6.QtCore.Qt.WindowType = ...) -> PySide6.QtDesigner.QDesignerFormWindowInterface: ...
    def createPreviewPixmap(self, /) -> PySide6.QtGui.QPixmap: ...
    def dragItems(self, item_list: collections.abc.Sequence[PySide6.QtDesigner.QDesignerDnDItemInterface], /) -> None: ...
    def formWindow(self, index: int, /) -> PySide6.QtDesigner.QDesignerFormWindowInterface: ...
    def formWindowCount(self, /) -> int: ...
    def removeFormWindow(self, formWindow: PySide6.QtDesigner.QDesignerFormWindowInterface, /) -> None: ...
    def setActiveFormWindow(self, formWindow: PySide6.QtDesigner.QDesignerFormWindowInterface, /) -> None: ...
    def showPluginDialog(self, /) -> None: ...
    def showPreview(self, /) -> None: ...


class QDesignerFormWindowToolInterface(PySide6.QtCore.QObject):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def action(self, /) -> PySide6.QtGui.QAction: ...
    def activated(self, /) -> None: ...
    def core(self, /) -> PySide6.QtDesigner.QDesignerFormEditorInterface: ...
    def deactivated(self, /) -> None: ...
    def editor(self, /) -> PySide6.QtWidgets.QWidget: ...
    def formWindow(self, /) -> PySide6.QtDesigner.QDesignerFormWindowInterface: ...
    def handleEvent(self, widget: PySide6.QtWidgets.QWidget, managedWidget: PySide6.QtWidgets.QWidget, event: PySide6.QtCore.QEvent, /) -> bool: ...


class QDesignerMemberSheetExtension(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def count(self, /) -> int: ...
    def declaredInClass(self, index: int, /) -> str: ...
    def indexOf(self, name: str, /) -> int: ...
    def inheritedFromWidget(self, index: int, /) -> bool: ...
    def isSignal(self, index: int, /) -> bool: ...
    def isSlot(self, index: int, /) -> bool: ...
    def isVisible(self, index: int, /) -> bool: ...
    def memberGroup(self, index: int, /) -> str: ...
    def memberName(self, index: int, /) -> str: ...
    def parameterNames(self, index: int, /) -> typing.List[PySide6.QtCore.QByteArray]: ...
    def parameterTypes(self, index: int, /) -> typing.List[PySide6.QtCore.QByteArray]: ...
    def setMemberGroup(self, index: int, group: str, /) -> None: ...
    def setVisible(self, index: int, b: bool, /) -> None: ...
    def signature(self, index: int, /) -> str: ...


class QDesignerObjectInspectorInterface(PySide6.QtWidgets.QWidget):

    def __init__(self, parent: PySide6.QtWidgets.QWidget, /, flags: PySide6.QtCore.Qt.WindowType = ...) -> None: ...

    def core(self, /) -> PySide6.QtDesigner.QDesignerFormEditorInterface: ...
    def setFormWindow(self, formWindow: PySide6.QtDesigner.QDesignerFormWindowInterface, /) -> None: ...


class QDesignerPropertyEditorInterface(PySide6.QtWidgets.QWidget):

    propertyChanged          : typing.ClassVar[Signal] = ... # propertyChanged(QString,QVariant)

    def __init__(self, parent: PySide6.QtWidgets.QWidget, /, flags: PySide6.QtCore.Qt.WindowType = ...) -> None: ...

    def core(self, /) -> PySide6.QtDesigner.QDesignerFormEditorInterface: ...
    def currentPropertyName(self, /) -> str: ...
    def isReadOnly(self, /) -> bool: ...
    def object(self, /) -> PySide6.QtCore.QObject: ...
    def setObject(self, object: PySide6.QtCore.QObject, /) -> None: ...
    def setPropertyValue(self, name: str, value: typing.Any, /, changed: bool = ...) -> None: ...
    def setReadOnly(self, readOnly: bool, /) -> None: ...


class QDesignerPropertySheetExtension(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def count(self, /) -> int: ...
    def hasReset(self, index: int, /) -> bool: ...
    def indexOf(self, name: str, /) -> int: ...
    def isAttribute(self, index: int, /) -> bool: ...
    def isChanged(self, index: int, /) -> bool: ...
    def isEnabled(self, index: int, /) -> bool: ...
    def isVisible(self, index: int, /) -> bool: ...
    def property(self, index: int, /) -> typing.Any: ...
    def propertyGroup(self, index: int, /) -> str: ...
    def propertyName(self, index: int, /) -> str: ...
    def reset(self, index: int, /) -> bool: ...
    def setAttribute(self, index: int, b: bool, /) -> None: ...
    def setChanged(self, index: int, changed: bool, /) -> None: ...
    def setProperty(self, index: int, value: typing.Any, /) -> None: ...
    def setPropertyGroup(self, index: int, group: str, /) -> None: ...
    def setVisible(self, index: int, b: bool, /) -> None: ...


class QDesignerTaskMenuExtension(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def preferredEditAction(self, /) -> PySide6.QtGui.QAction: ...
    def taskActions(self, /) -> typing.List[PySide6.QtGui.QAction]: ...


class QDesignerWidgetBoxInterface(PySide6.QtWidgets.QWidget):

    class Category(Shiboken.Object):

        class Type(enum.Enum):

            Default                   = 0x0
            Scratchpad                = 0x1


        @typing.overload
        def __init__(self, Category: PySide6.QtDesigner.QDesignerWidgetBoxInterface.Category, /) -> None: ...
        @typing.overload
        def __init__(self, /, aname: str = ..., atype: PySide6.QtDesigner.QDesignerWidgetBoxInterface.Category.Type = ...) -> None: ...

        def __copy__(self, /) -> typing.Self: ...
        def addWidget(self, awidget: PySide6.QtDesigner.QDesignerWidgetBoxInterface.Widget, /) -> None: ...
        def isNull(self, /) -> bool: ...
        def name(self, /) -> str: ...
        def removeWidget(self, idx: int, /) -> None: ...
        def setName(self, aname: str, /) -> None: ...
        def setType(self, atype: PySide6.QtDesigner.QDesignerWidgetBoxInterface.Category.Type, /) -> None: ...
        def type(self, /) -> PySide6.QtDesigner.QDesignerWidgetBoxInterface.Category.Type: ...
        def widget(self, idx: int, /) -> PySide6.QtDesigner.QDesignerWidgetBoxInterface.Widget: ...
        def widgetCount(self, /) -> int: ...

    class Widget(Shiboken.Object):

        class Type(enum.Enum):

            Default                   = 0x0
            Custom                    = 0x1


        @typing.overload
        def __init__(self, w: PySide6.QtDesigner.QDesignerWidgetBoxInterface.Widget, /) -> None: ...
        @typing.overload
        def __init__(self, /, aname: str = ..., xml: str = ..., icon_name: str = ..., atype: PySide6.QtDesigner.QDesignerWidgetBoxInterface.Widget.Type = ...) -> None: ...

        def __copy__(self, /) -> typing.Self: ...
        def domXml(self, /) -> str: ...
        def iconName(self, /) -> str: ...
        def isNull(self, /) -> bool: ...
        def name(self, /) -> str: ...
        def setDomXml(self, xml: str, /) -> None: ...
        def setIconName(self, icon_name: str, /) -> None: ...
        def setName(self, aname: str, /) -> None: ...
        def setType(self, atype: PySide6.QtDesigner.QDesignerWidgetBoxInterface.Widget.Type, /) -> None: ...
        def type(self, /) -> PySide6.QtDesigner.QDesignerWidgetBoxInterface.Widget.Type: ...


    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ..., flags: PySide6.QtCore.Qt.WindowType = ...) -> None: ...

    def addCategory(self, cat: PySide6.QtDesigner.QDesignerWidgetBoxInterface.Category, /) -> None: ...
    def addWidget(self, cat_idx: int, wgt: PySide6.QtDesigner.QDesignerWidgetBoxInterface.Widget, /) -> None: ...
    def category(self, cat_idx: int, /) -> PySide6.QtDesigner.QDesignerWidgetBoxInterface.Category: ...
    def categoryCount(self, /) -> int: ...
    def dropWidgets(self, item_list: collections.abc.Sequence[PySide6.QtDesigner.QDesignerDnDItemInterface], global_mouse_pos: PySide6.QtCore.QPoint, /) -> None: ...
    def fileName(self, /) -> str: ...
    def findOrInsertCategory(self, categoryName: str, /) -> int: ...
    def load(self, /) -> bool: ...
    def removeCategory(self, cat_idx: int, /) -> None: ...
    def removeWidget(self, cat_idx: int, wgt_idx: int, /) -> None: ...
    def save(self, /) -> bool: ...
    def setFileName(self, file_name: str, /) -> None: ...
    def widget(self, cat_idx: int, wgt_idx: int, /) -> PySide6.QtDesigner.QDesignerWidgetBoxInterface.Widget: ...
    def widgetCount(self, cat_idx: int, /) -> int: ...


class QExtensionFactory(PySide6.QtCore.QObject, PySide6.QtDesigner.QAbstractExtensionFactory):

    def __init__(self, /, parent: PySide6.QtDesigner.QExtensionManager | None = ...) -> None: ...

    def createExtension(self, object: PySide6.QtCore.QObject, iid: str, parent: PySide6.QtCore.QObject, /) -> PySide6.QtCore.QObject: ...
    def extension(self, object: PySide6.QtCore.QObject, iid: str, /) -> PySide6.QtCore.QObject: ...
    def extensionManager(self, /) -> PySide6.QtDesigner.QExtensionManager: ...


class QExtensionManager(PySide6.QtCore.QObject, PySide6.QtDesigner.QAbstractExtensionManager):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def extension(self, object: PySide6.QtCore.QObject, iid: str, /) -> PySide6.QtCore.QObject: ...
    def registerExtensions(self, factory: PySide6.QtDesigner.QAbstractExtensionFactory, /, iid: str = ...) -> None: ...
    def unregisterExtensions(self, factory: PySide6.QtDesigner.QAbstractExtensionFactory, /, iid: str = ...) -> None: ...


class QFormBuilder(PySide6.QtDesigner.QAbstractFormBuilder):

    def __init__(self, /) -> None: ...

    def addPluginPath(self, pluginPath: str, /) -> None: ...
    def clearPluginPaths(self, /) -> None: ...
    def createLayout(self, layoutName: str, parent: PySide6.QtCore.QObject, name: str, /) -> PySide6.QtWidgets.QLayout: ...
    def createWidget(self, widgetName: str, parentWidget: PySide6.QtWidgets.QWidget, name: str, /) -> PySide6.QtWidgets.QWidget: ...
    def customWidgets(self, /) -> typing.List[PySide6.QtDesigner.QDesignerCustomWidgetInterface]: ...
    def pluginPaths(self, /) -> typing.List[str]: ...
    def setPluginPath(self, pluginPaths: collections.abc.Sequence[str], /) -> None: ...
    def updateCustomWidgets(self, /) -> None: ...
    @staticmethod
    def widgetByName(topLevel: PySide6.QtWidgets.QWidget, name: str, /) -> PySide6.QtWidgets.QWidget: ...


class QIntList: ...


class QPyDesignerContainerExtension(PySide6.QtCore.QObject, PySide6.QtDesigner.QDesignerContainerExtension):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...


class QPyDesignerCustomWidgetCollection(PySide6.QtDesigner.QDesignerCustomWidgetCollectionInterface):
    @staticmethod
    def addCustomWidget(c: PySide6.QtDesigner.QDesignerCustomWidgetInterface, /) -> None: ...
    def customWidgets(self, /) -> typing.List[PySide6.QtDesigner.QDesignerCustomWidgetInterface]: ...
    @staticmethod
    def instance() -> PySide6.QtDesigner.QPyDesignerCustomWidgetCollection: ...
    @staticmethod
    def registerCustomWidget(customWidgetType: object, /, xml: str = ..., tool_tip: str = ..., group: str = ..., module: str = ..., container: bool = ..., icon: str = ...) -> None: ...


class QPyDesignerMemberSheetExtension(PySide6.QtCore.QObject, PySide6.QtDesigner.QDesignerMemberSheetExtension):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...


class QPyDesignerPropertySheetExtension(PySide6.QtCore.QObject, PySide6.QtDesigner.QDesignerPropertySheetExtension):  # type: ignore[misc]

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...


class QPyDesignerTaskMenuExtension(PySide6.QtCore.QObject, PySide6.QtDesigner.QDesignerTaskMenuExtension):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtWebEngineWidgets, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtWebEngineWidgets`

import PySide6.QtWebEngineWidgets
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtWidgets
import PySide6.QtPrintSupport
import PySide6.QtWebEngineCore

import typing
import collections.abc
from PySide6.QtCore import Signal


class QIntList: ...


class QWebEngineView(PySide6.QtWidgets.QWidget):

    iconChanged              : typing.ClassVar[Signal] = ... # iconChanged(QIcon)
    iconUrlChanged           : typing.ClassVar[Signal] = ... # iconUrlChanged(QUrl)
    loadFinished             : typing.ClassVar[Signal] = ... # loadFinished(bool)
    loadProgress             : typing.ClassVar[Signal] = ... # loadProgress(int)
    loadStarted              : typing.ClassVar[Signal] = ... # loadStarted()
    pdfPrintingFinished      : typing.ClassVar[Signal] = ... # pdfPrintingFinished(QString,bool)
    printFinished            : typing.ClassVar[Signal] = ... # printFinished(bool)
    printRequested           : typing.ClassVar[Signal] = ... # printRequested()
    printRequestedByFrame    : typing.ClassVar[Signal] = ... # printRequestedByFrame(QWebEngineFrame)
    renderProcessTerminated  : typing.ClassVar[Signal] = ... # renderProcessTerminated(QWebEnginePage::RenderProcessTerminationStatus,int)
    selectionChanged         : typing.ClassVar[Signal] = ... # selectionChanged()
    titleChanged             : typing.ClassVar[Signal] = ... # titleChanged(QString)
    urlChanged               : typing.ClassVar[Signal] = ... # urlChanged(QUrl)

    @typing.overload
    def __init__(self, page: PySide6.QtWebEngineCore.QWebEnginePage, /, parent: PySide6.QtWidgets.QWidget | None = ..., *, title: str | None = ..., url: PySide6.QtCore.QUrl | None = ..., iconUrl: PySide6.QtCore.QUrl | None = ..., icon: PySide6.QtGui.QIcon | None = ..., selectedText: str | None = ..., hasSelection: bool | None = ..., zoomFactor: float | None = ...) -> None: ...
    @typing.overload
    def __init__(self, profile: PySide6.QtWebEngineCore.QWebEngineProfile, /, parent: PySide6.QtWidgets.QWidget | None = ..., *, title: str | None = ..., url: PySide6.QtCore.QUrl | None = ..., iconUrl: PySide6.QtCore.QUrl | None = ..., icon: PySide6.QtGui.QIcon | None = ..., selectedText: str | None = ..., hasSelection: bool | None = ..., zoomFactor: float | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ..., *, title: str | None = ..., url: PySide6.QtCore.QUrl | None = ..., iconUrl: PySide6.QtCore.QUrl | None = ..., icon: PySide6.QtGui.QIcon | None = ..., selectedText: str | None = ..., hasSelection: bool | None = ..., zoomFactor: float | None = ...) -> None: ...

    def back(self, /) -> None: ...
    def closeEvent(self, arg__1: PySide6.QtGui.QCloseEvent, /) -> None: ...
    def contextMenuEvent(self, arg__1: PySide6.QtGui.QContextMenuEvent, /) -> None: ...
    def createStandardContextMenu(self, /) -> PySide6.QtWidgets.QMenu: ...
    def createWindow(self, type: PySide6.QtWebEngineCore.QWebEnginePage.WebWindowType, /) -> PySide6.QtWebEngineWidgets.QWebEngineView: ...
    def dragEnterEvent(self, e: PySide6.QtGui.QDragEnterEvent, /) -> None: ...
    def dragLeaveEvent(self, e: PySide6.QtGui.QDragLeaveEvent, /) -> None: ...
    def dragMoveEvent(self, e: PySide6.QtGui.QDragMoveEvent, /) -> None: ...
    def dropEvent(self, e: PySide6.QtGui.QDropEvent, /) -> None: ...
    def event(self, arg__1: PySide6.QtCore.QEvent, /) -> bool: ...
    @typing.overload
    def findText(self, subString: str, /, options: PySide6.QtWebEngineCore.QWebEnginePage.FindFlag = ...) -> None: ...
    @typing.overload
    def findText(self, subString: str, options: PySide6.QtWebEngineCore.QWebEnginePage.FindFlag, resultCallback: collections.abc.Callable[..., typing.Any], /) -> None: ...
    @staticmethod
    def forPage(page: PySide6.QtWebEngineCore.QWebEnginePage, /) -> PySide6.QtWebEngineWidgets.QWebEngineView: ...
    def forward(self, /) -> None: ...
    def hasSelection(self, /) -> bool: ...
    def hideEvent(self, arg__1: PySide6.QtGui.QHideEvent, /) -> None: ...
    def history(self, /) -> PySide6.QtWebEngineCore.QWebEngineHistory: ...
    def icon(self, /) -> PySide6.QtGui.QIcon: ...
    def iconUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def lastContextMenuRequest(self, /) -> PySide6.QtWebEngineCore.QWebEngineContextMenuRequest: ...
    @typing.overload
    def load(self, request: PySide6.QtWebEngineCore.QWebEngineHttpRequest, /) -> None: ...
    @typing.overload
    def load(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def page(self, /) -> PySide6.QtWebEngineCore.QWebEnginePage: ...
    def pageAction(self, action: PySide6.QtWebEngineCore.QWebEnginePage.WebAction, /) -> PySide6.QtGui.QAction: ...
    def print(self, printer: PySide6.QtPrintSupport.QPrinter, /) -> None: ...
    def printToPdf(self, filePath: str, /, layout: PySide6.QtGui.QPageLayout = ..., ranges: PySide6.QtGui.QPageRanges = ...) -> None: ...
    def reload(self, /) -> None: ...
    def selectedText(self, /) -> str: ...
    def setContent(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /, mimeType: str = ..., baseUrl: PySide6.QtCore.QUrl | str = ...) -> None: ...
    def setHtml(self, html: str, /, baseUrl: PySide6.QtCore.QUrl | str = ...) -> None: ...
    def setPage(self, page: PySide6.QtWebEngineCore.QWebEnginePage, /) -> None: ...
    def setUrl(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    def setZoomFactor(self, factor: float, /) -> None: ...
    def settings(self, /) -> PySide6.QtWebEngineCore.QWebEngineSettings: ...
    def showEvent(self, arg__1: PySide6.QtGui.QShowEvent, /) -> None: ...
    def sizeHint(self, /) -> PySide6.QtCore.QSize: ...
    def stop(self, /) -> None: ...
    def title(self, /) -> str: ...
    def triggerPageAction(self, action: PySide6.QtWebEngineCore.QWebEnginePage.WebAction, /, checked: bool = ...) -> None: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...
    def zoomFactor(self, /) -> float: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtPrintSupport, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtPrintSupport`

import PySide6.QtPrintSupport
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtWidgets

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QAbstractPrintDialog(PySide6.QtWidgets.QDialog):

    class PrintDialogOption(enum.Flag):

        PrintToFile               = 0x1
        PrintSelection            = 0x2
        PrintPageRange            = 0x4
        PrintShowPageSize         = 0x8
        PrintCollateCopies        = 0x10
        PrintCurrentPage          = 0x40

    class PrintRange(enum.Enum):

        AllPages                  = 0x0
        Selection                 = 0x1
        PageRange                 = 0x2
        CurrentPage               = 0x3


    def __init__(self, printer: PySide6.QtPrintSupport.QPrinter, /, parent: PySide6.QtWidgets.QWidget | None = ...) -> None: ...

    def fromPage(self, /) -> int: ...
    def maxPage(self, /) -> int: ...
    def minPage(self, /) -> int: ...
    def printRange(self, /) -> PySide6.QtPrintSupport.QAbstractPrintDialog.PrintRange: ...
    def printer(self, /) -> PySide6.QtPrintSupport.QPrinter: ...
    def setFromTo(self, fromPage: int, toPage: int, /) -> None: ...
    def setMinMax(self, min: int, max: int, /) -> None: ...
    def setOptionTabs(self, tabs: collections.abc.Sequence[PySide6.QtWidgets.QWidget], /) -> None: ...
    def setPrintRange(self, range: PySide6.QtPrintSupport.QAbstractPrintDialog.PrintRange, /) -> None: ...
    def toPage(self, /) -> int: ...


class QIntList: ...


class QPageSetupDialog(PySide6.QtWidgets.QDialog):

    @typing.overload
    def __init__(self, printer: PySide6.QtPrintSupport.QPrinter, /, parent: PySide6.QtWidgets.QWidget | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ...) -> None: ...

    def done(self, result: int, /) -> None: ...
    def exec(self, /) -> int: ...
    def exec_(self, /) -> int: ...
    @typing.overload
    def open(self, /) -> None: ...
    @typing.overload
    def open(self, receiver: PySide6.QtCore.QObject, member: bytes | bytearray | memoryview, /) -> None: ...
    def printer(self, /) -> PySide6.QtPrintSupport.QPrinter: ...


class QPrintDialog(PySide6.QtPrintSupport.QAbstractPrintDialog):

    accepted                 : typing.ClassVar[Signal] = ... # accepted(QPrinter*)

    @typing.overload
    def __init__(self, printer: PySide6.QtPrintSupport.QPrinter, /, parent: PySide6.QtWidgets.QWidget | None = ..., *, options: PySide6.QtPrintSupport.QAbstractPrintDialog.PrintDialogOption | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ..., *, options: PySide6.QtPrintSupport.QAbstractPrintDialog.PrintDialogOption | None = ...) -> None: ...

    def accept(self, /) -> None: ...
    def done(self, result: int, /) -> None: ...
    def exec(self, /) -> int: ...
    def exec_(self, /) -> int: ...
    def open(self, receiver: PySide6.QtCore.QObject, member: bytes | bytearray | memoryview, /) -> None: ...
    def options(self, /) -> PySide6.QtPrintSupport.QAbstractPrintDialog.PrintDialogOption: ...
    def setOption(self, option: PySide6.QtPrintSupport.QAbstractPrintDialog.PrintDialogOption, /, on: bool = ...) -> None: ...
    def setOptions(self, options: PySide6.QtPrintSupport.QAbstractPrintDialog.PrintDialogOption, /) -> None: ...
    def setVisible(self, visible: bool, /) -> None: ...
    def testOption(self, option: PySide6.QtPrintSupport.QAbstractPrintDialog.PrintDialogOption, /) -> bool: ...


class QPrintEngine(Shiboken.Object):

    class PrintEnginePropertyKey(enum.Enum):

        PPK_CollateCopies         = 0x0
        PPK_ColorMode             = 0x1
        PPK_Creator               = 0x2
        PPK_DocumentName          = 0x3
        PPK_FullPage              = 0x4
        PPK_NumberOfCopies        = 0x5
        PPK_Orientation           = 0x6
        PPK_OutputFileName        = 0x7
        PPK_PageOrder             = 0x8
        PPK_PageRect              = 0x9
        PPK_PageSize              = 0xa
        PPK_PaperSize             = 0xa
        PPK_PaperRect             = 0xb
        PPK_PaperSource           = 0xc
        PPK_PrinterName           = 0xd
        PPK_PrinterProgram        = 0xe
        PPK_Resolution            = 0xf
        PPK_SelectionOption       = 0x10
        PPK_SupportedResolutions  = 0x11
        PPK_WindowsPageSize       = 0x12
        PPK_FontEmbedding         = 0x13
        PPK_Duplex                = 0x14
        PPK_PaperSources          = 0x15
        PPK_CustomPaperSize       = 0x16
        PPK_PageMargins           = 0x17
        PPK_CopyCount             = 0x18
        PPK_SupportsMultipleCopies = 0x19
        PPK_PaperName             = 0x1a
        PPK_QPageSize             = 0x1b
        PPK_QPageMargins          = 0x1c
        PPK_QPageLayout           = 0x1d
        PPK_CustomBase            = 0xff00


    def __init__(self, /) -> None: ...

    def abort(self, /) -> bool: ...
    def metric(self, arg__1: PySide6.QtGui.QPaintDevice.PaintDeviceMetric, /) -> int: ...
    def newPage(self, /) -> bool: ...
    def printerState(self, /) -> PySide6.QtPrintSupport.QPrinter.PrinterState: ...
    def property(self, key: PySide6.QtPrintSupport.QPrintEngine.PrintEnginePropertyKey, /) -> typing.Any: ...
    def setProperty(self, key: PySide6.QtPrintSupport.QPrintEngine.PrintEnginePropertyKey, value: typing.Any, /) -> None: ...


class QPrintPreviewDialog(PySide6.QtWidgets.QDialog):

    paintRequested           : typing.ClassVar[Signal] = ... # paintRequested(QPrinter*)

    @typing.overload
    def __init__(self, printer: PySide6.QtPrintSupport.QPrinter, /, parent: PySide6.QtWidgets.QWidget | None = ..., flags: PySide6.QtCore.Qt.WindowType = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ..., flags: PySide6.QtCore.Qt.WindowType = ...) -> None: ...

    def done(self, result: int, /) -> None: ...
    @typing.overload
    def open(self, /) -> None: ...
    @typing.overload
    def open(self, receiver: PySide6.QtCore.QObject, member: bytes | bytearray | memoryview, /) -> None: ...
    def printer(self, /) -> PySide6.QtPrintSupport.QPrinter: ...
    def setVisible(self, visible: bool, /) -> None: ...


class QPrintPreviewWidget(PySide6.QtWidgets.QWidget):

    paintRequested           : typing.ClassVar[Signal] = ... # paintRequested(QPrinter*)
    previewChanged           : typing.ClassVar[Signal] = ... # previewChanged()

    class ViewMode(enum.Enum):

        SinglePageView            = 0x0
        FacingPagesView           = 0x1
        AllPagesView              = 0x2

    class ZoomMode(enum.Enum):

        CustomZoom                = 0x0
        FitToWidth                = 0x1
        FitInView                 = 0x2


    @typing.overload
    def __init__(self, printer: PySide6.QtPrintSupport.QPrinter, /, parent: PySide6.QtWidgets.QWidget | None = ..., flags: PySide6.QtCore.Qt.WindowType = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ..., flags: PySide6.QtCore.Qt.WindowType = ...) -> None: ...

    def currentPage(self, /) -> int: ...
    def fitInView(self, /) -> None: ...
    def fitToWidth(self, /) -> None: ...
    def orientation(self, /) -> PySide6.QtGui.QPageLayout.Orientation: ...
    def pageCount(self, /) -> int: ...
    def print_(self, /) -> None: ...
    def setAllPagesViewMode(self, /) -> None: ...
    def setCurrentPage(self, pageNumber: int, /) -> None: ...
    def setFacingPagesViewMode(self, /) -> None: ...
    def setLandscapeOrientation(self, /) -> None: ...
    def setOrientation(self, orientation: PySide6.QtGui.QPageLayout.Orientation, /) -> None: ...
    def setPortraitOrientation(self, /) -> None: ...
    def setSinglePageViewMode(self, /) -> None: ...
    def setViewMode(self, viewMode: PySide6.QtPrintSupport.QPrintPreviewWidget.ViewMode, /) -> None: ...
    def setVisible(self, visible: bool, /) -> None: ...
    def setZoomFactor(self, zoomFactor: float, /) -> None: ...
    def setZoomMode(self, zoomMode: PySide6.QtPrintSupport.QPrintPreviewWidget.ZoomMode, /) -> None: ...
    def updatePreview(self, /) -> None: ...
    def viewMode(self, /) -> PySide6.QtPrintSupport.QPrintPreviewWidget.ViewMode: ...
    def zoomFactor(self, /) -> float: ...
    def zoomIn(self, /, zoom: float = ...) -> None: ...
    def zoomMode(self, /) -> PySide6.QtPrintSupport.QPrintPreviewWidget.ZoomMode: ...
    def zoomOut(self, /, zoom: float = ...) -> None: ...


class QPrinter(PySide6.QtGui.QPagedPaintDevice):

    class ColorMode(enum.Enum):

        GrayScale                 = 0x0
        Color                     = 0x1

    class DuplexMode(enum.Enum):

        DuplexNone                = 0x0
        DuplexAuto                = 0x1
        DuplexLongSide            = 0x2
        DuplexShortSide           = 0x3

    class OutputFormat(enum.Enum):

        NativeFormat              = 0x0
        PdfFormat                 = 0x1

    class PageOrder(enum.Enum):

        FirstPageFirst            = 0x0
        LastPageFirst             = 0x1

    class PaperSource(enum.Enum):

        OnlyOne                   = 0x0
        Upper                     = 0x0
        Lower                     = 0x1
        Middle                    = 0x2
        Manual                    = 0x3
        Envelope                  = 0x4
        EnvelopeManual            = 0x5
        Auto                      = 0x6
        Tractor                   = 0x7
        SmallFormat               = 0x8
        LargeFormat               = 0x9
        LargeCapacity             = 0xa
        Cassette                  = 0xb
        FormSource                = 0xc
        MaxPageSource             = 0xd
        CustomSource              = 0xe
        LastPaperSource           = 0xe

    class PrintRange(enum.Enum):

        AllPages                  = 0x0
        Selection                 = 0x1
        PageRange                 = 0x2
        CurrentPage               = 0x3

    class PrinterMode(enum.Enum):

        ScreenResolution          = 0x0
        PrinterResolution         = 0x1
        HighResolution            = 0x2

    class PrinterState(enum.Enum):

        Idle                      = 0x0
        Active                    = 0x1
        Aborted                   = 0x2
        Error                     = 0x3

    class Unit(enum.Enum):

        Millimeter                = 0x0
        Point                     = 0x1
        Inch                      = 0x2
        Pica                      = 0x3
        Didot                     = 0x4
        Cicero                    = 0x5
        DevicePixel               = 0x6


    @typing.overload
    def __init__(self, /, mode: PySide6.QtPrintSupport.QPrinter.PrinterMode = ...) -> None: ...
    @typing.overload
    def __init__(self, printer: PySide6.QtPrintSupport.QPrinterInfo, /, mode: PySide6.QtPrintSupport.QPrinter.PrinterMode = ...) -> None: ...

    def abort(self, /) -> bool: ...
    def collateCopies(self, /) -> bool: ...
    def colorMode(self, /) -> PySide6.QtPrintSupport.QPrinter.ColorMode: ...
    def copyCount(self, /) -> int: ...
    def creator(self, /) -> str: ...
    def devType(self, /) -> int: ...
    def docName(self, /) -> str: ...
    def duplex(self, /) -> PySide6.QtPrintSupport.QPrinter.DuplexMode: ...
    def fontEmbeddingEnabled(self, /) -> bool: ...
    def fromPage(self, /) -> int: ...
    def fullPage(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def metric(self, arg__1: PySide6.QtGui.QPaintDevice.PaintDeviceMetric, /) -> int: ...
    def newPage(self, /) -> bool: ...
    def outputFileName(self, /) -> str: ...
    def outputFormat(self, /) -> PySide6.QtPrintSupport.QPrinter.OutputFormat: ...
    def pageOrder(self, /) -> PySide6.QtPrintSupport.QPrinter.PageOrder: ...
    def pageRect(self, arg__1: PySide6.QtPrintSupport.QPrinter.Unit, /) -> PySide6.QtCore.QRectF: ...
    def paintEngine(self, /) -> PySide6.QtGui.QPaintEngine: ...
    def paperRect(self, arg__1: PySide6.QtPrintSupport.QPrinter.Unit, /) -> PySide6.QtCore.QRectF: ...
    def paperSource(self, /) -> PySide6.QtPrintSupport.QPrinter.PaperSource: ...
    def pdfVersion(self, /) -> PySide6.QtGui.QPagedPaintDevice.PdfVersion: ...
    def printEngine(self, /) -> PySide6.QtPrintSupport.QPrintEngine: ...
    def printProgram(self, /) -> str: ...
    def printRange(self, /) -> PySide6.QtPrintSupport.QPrinter.PrintRange: ...
    def printerName(self, /) -> str: ...
    def printerSelectionOption(self, /) -> str: ...
    def printerState(self, /) -> PySide6.QtPrintSupport.QPrinter.PrinterState: ...
    def resolution(self, /) -> int: ...
    def setCollateCopies(self, collate: bool, /) -> None: ...
    def setColorMode(self, arg__1: PySide6.QtPrintSupport.QPrinter.ColorMode, /) -> None: ...
    def setCopyCount(self, arg__1: int, /) -> None: ...
    def setCreator(self, arg__1: str, /) -> None: ...
    def setDocName(self, arg__1: str, /) -> None: ...
    def setDuplex(self, duplex: PySide6.QtPrintSupport.QPrinter.DuplexMode, /) -> None: ...
    def setEngines(self, printEngine: PySide6.QtPrintSupport.QPrintEngine, paintEngine: PySide6.QtGui.QPaintEngine, /) -> None: ...
    def setFontEmbeddingEnabled(self, enable: bool, /) -> None: ...
    def setFromTo(self, fromPage: int, toPage: int, /) -> None: ...
    def setFullPage(self, arg__1: bool, /) -> None: ...
    def setOutputFileName(self, arg__1: str, /) -> None: ...
    def setOutputFormat(self, format: PySide6.QtPrintSupport.QPrinter.OutputFormat, /) -> None: ...
    def setPageOrder(self, arg__1: PySide6.QtPrintSupport.QPrinter.PageOrder, /) -> None: ...
    def setPageSize(self, size: PySide6.QtGui.QPageSize | PySide6.QtGui.QPageSize.PageSizeId | PySide6.QtCore.QSize, /) -> bool: ...
    def setPaperSource(self, arg__1: PySide6.QtPrintSupport.QPrinter.PaperSource, /) -> None: ...
    def setPdfVersion(self, version: PySide6.QtGui.QPagedPaintDevice.PdfVersion, /) -> None: ...
    def setPrintProgram(self, arg__1: str, /) -> None: ...
    def setPrintRange(self, range: PySide6.QtPrintSupport.QPrinter.PrintRange, /) -> None: ...
    def setPrinterName(self, arg__1: str, /) -> None: ...
    def setPrinterSelectionOption(self, arg__1: str, /) -> None: ...
    def setResolution(self, arg__1: int, /) -> None: ...
    def supportedResolutions(self, /) -> typing.List[int]: ...
    def supportsMultipleCopies(self, /) -> bool: ...
    def toPage(self, /) -> int: ...


class QPrinterInfo(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, printer: PySide6.QtPrintSupport.QPrinter, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtPrintSupport.QPrinterInfo, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    @staticmethod
    def availablePrinterNames() -> typing.List[str]: ...
    @staticmethod
    def availablePrinters() -> typing.List[PySide6.QtPrintSupport.QPrinterInfo]: ...
    def defaultColorMode(self, /) -> PySide6.QtPrintSupport.QPrinter.ColorMode: ...
    def defaultDuplexMode(self, /) -> PySide6.QtPrintSupport.QPrinter.DuplexMode: ...
    def defaultPageSize(self, /) -> PySide6.QtGui.QPageSize: ...
    @staticmethod
    def defaultPrinter() -> PySide6.QtPrintSupport.QPrinterInfo: ...
    @staticmethod
    def defaultPrinterName() -> str: ...
    def description(self, /) -> str: ...
    def isDefault(self, /) -> bool: ...
    def isNull(self, /) -> bool: ...
    def isRemote(self, /) -> bool: ...
    def location(self, /) -> str: ...
    def makeAndModel(self, /) -> str: ...
    def maximumPhysicalPageSize(self, /) -> PySide6.QtGui.QPageSize: ...
    def minimumPhysicalPageSize(self, /) -> PySide6.QtGui.QPageSize: ...
    @staticmethod
    def printerInfo(printerName: str, /) -> PySide6.QtPrintSupport.QPrinterInfo: ...
    def printerName(self, /) -> str: ...
    def state(self, /) -> PySide6.QtPrintSupport.QPrinter.PrinterState: ...
    def supportedColorModes(self, /) -> typing.List[PySide6.QtPrintSupport.QPrinter.ColorMode]: ...
    def supportedDuplexModes(self, /) -> typing.List[PySide6.QtPrintSupport.QPrinter.DuplexMode]: ...
    def supportedPageSizes(self, /) -> typing.List[PySide6.QtGui.QPageSize]: ...
    def supportedResolutions(self, /) -> typing.List[int]: ...
    def supportsCustomPageSizes(self, /) -> bool: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.Qt3DAnimation, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.Qt3DAnimation`

import PySide6.Qt3DAnimation
import PySide6.QtCore
import PySide6.QtGui
import PySide6.Qt3DCore
import PySide6.Qt3DRender

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class Qt3DAnimation(Shiboken.Object):

    class QAbstractAnimation(PySide6.QtCore.QObject):

        animationNameChanged     : typing.ClassVar[Signal] = ... # animationNameChanged(QString)
        durationChanged          : typing.ClassVar[Signal] = ... # durationChanged(float)
        positionChanged          : typing.ClassVar[Signal] = ... # positionChanged(float)

        class AnimationType(enum.Enum):

            KeyframeAnimation         = 0x1
            MorphingAnimation         = 0x2
            VertexBlendAnimation      = 0x3


        def animationName(self, /) -> str: ...
        def animationType(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimation.AnimationType: ...
        def duration(self, /) -> float: ...
        def position(self, /) -> float: ...
        def setAnimationName(self, name: str, /) -> None: ...
        def setDuration(self, duration: float, /) -> None: ...
        def setPosition(self, position: float, /) -> None: ...

    class QAbstractAnimationClip(PySide6.Qt3DCore.Qt3DCore.QNode):

        durationChanged          : typing.ClassVar[Signal] = ... # durationChanged(float)
        def duration(self, /) -> float: ...

    class QAbstractChannelMapping(PySide6.Qt3DCore.Qt3DCore.QNode): ...

    class QAbstractClipAnimator(PySide6.Qt3DCore.Qt3DCore.QComponent):

        channelMapperChanged     : typing.ClassVar[Signal] = ... # channelMapperChanged(Qt3DAnimation::QChannelMapper*)
        clockChanged             : typing.ClassVar[Signal] = ... # clockChanged(Qt3DAnimation::QClock*)
        loopCountChanged         : typing.ClassVar[Signal] = ... # loopCountChanged(int)
        normalizedTimeChanged    : typing.ClassVar[Signal] = ... # normalizedTimeChanged(float)
        runningChanged           : typing.ClassVar[Signal] = ... # runningChanged(bool)

        class Loops(enum.Enum):

            Infinite                  = -1


        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, running: bool | None = ..., loops: int | None = ..., channelMapper: PySide6.Qt3DAnimation.Qt3DAnimation.QChannelMapper | None = ..., clock: PySide6.Qt3DAnimation.Qt3DAnimation.QClock | None = ..., normalizedTime: float | None = ...) -> None: ...

        def channelMapper(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QChannelMapper: ...
        def clock(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QClock: ...
        def isRunning(self, /) -> bool: ...
        def loopCount(self, /) -> int: ...
        def normalizedTime(self, /) -> float: ...
        def setChannelMapper(self, channelMapper: PySide6.Qt3DAnimation.Qt3DAnimation.QChannelMapper, /) -> None: ...
        def setClock(self, clock: PySide6.Qt3DAnimation.Qt3DAnimation.QClock, /) -> None: ...
        def setLoopCount(self, loops: int, /) -> None: ...
        def setNormalizedTime(self, timeFraction: float, /) -> None: ...
        def setRunning(self, running: bool, /) -> None: ...
        def start(self, /) -> None: ...
        def stop(self, /) -> None: ...

    class QAbstractClipBlendNode(PySide6.Qt3DCore.Qt3DCore.QNode):

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ...) -> None: ...


    class QAdditiveClipBlend(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode):

        additiveClipChanged      : typing.ClassVar[Signal] = ... # additiveClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)
        additiveFactorChanged    : typing.ClassVar[Signal] = ... # additiveFactorChanged(float)
        baseClipChanged          : typing.ClassVar[Signal] = ... # baseClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, baseClip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode | None = ..., additiveClip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode | None = ..., additiveFactor: float | None = ...) -> None: ...

        def additiveClip(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode: ...
        def additiveFactor(self, /) -> float: ...
        def baseClip(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode: ...
        def setAdditiveClip(self, additiveClip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode, /) -> None: ...
        def setAdditiveFactor(self, additiveFactor: float, /) -> None: ...
        def setBaseClip(self, baseClip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode, /) -> None: ...

    class QAnimationAspect(PySide6.Qt3DCore.Qt3DCore.QAbstractAspect):

        def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...


    class QAnimationCallback(Shiboken.Object):

        class Flag(enum.Flag):

            OnOwningThread            = 0x0
            OnThreadPool              = 0x1


        def __init__(self, /) -> None: ...

        def valueChanged(self, value: typing.Any, /) -> None: ...

    class QAnimationClip(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimationClip):

        clipDataChanged          : typing.ClassVar[Signal] = ... # clipDataChanged(Qt3DAnimation::QAnimationClipData)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, clipData: PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationClipData | None = ...) -> None: ...

        def clipData(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationClipData: ...
        def setClipData(self, clipData: PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationClipData, /) -> None: ...

    class QAnimationClipData(Shiboken.Object):

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, arg__1: PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationClipData, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...
        def __eq__(self, rhs: PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationClipData, /) -> bool: ...
        def __ne__(self, rhs: PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationClipData, /) -> bool: ...
        def appendChannel(self, c: PySide6.Qt3DAnimation.Qt3DAnimation.QChannel, /) -> None: ...
        def begin(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QChannel: ...
        def cbegin(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QChannel: ...
        def cend(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QChannel: ...
        def channelCount(self, /) -> int: ...
        def clearChannels(self, /) -> None: ...
        def end(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QChannel: ...
        def insertChannel(self, index: int, c: PySide6.Qt3DAnimation.Qt3DAnimation.QChannel, /) -> None: ...
        def isValid(self, /) -> bool: ...
        def name(self, /) -> str: ...
        def removeChannel(self, index: int, /) -> None: ...
        def setName(self, name: str, /) -> None: ...

    class QAnimationClipLoader(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimationClip):

        sourceChanged            : typing.ClassVar[Signal] = ... # sourceChanged(QUrl)
        statusChanged            : typing.ClassVar[Signal] = ... # statusChanged(Status)

        class Status(enum.Enum):

            NotReady                  = 0x0
            Ready                     = 0x1
            Error                     = 0x2


        @typing.overload
        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, source: PySide6.QtCore.QUrl | None = ..., status: PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationClipLoader.Status | None = ...) -> None: ...
        @typing.overload
        def __init__(self, source: PySide6.QtCore.QUrl | str, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, status: PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationClipLoader.Status | None = ...) -> None: ...

        def setSource(self, source: PySide6.QtCore.QUrl | str, /) -> None: ...
        def source(self, /) -> PySide6.QtCore.QUrl: ...
        def status(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationClipLoader.Status: ...

    class QAnimationController(PySide6.QtCore.QObject):

        activeAnimationGroupChanged: typing.ClassVar[Signal] = ... # activeAnimationGroupChanged(int)
        entityChanged            : typing.ClassVar[Signal] = ... # entityChanged(Qt3DCore::QEntity*)
        positionChanged          : typing.ClassVar[Signal] = ... # positionChanged(float)
        positionOffsetChanged    : typing.ClassVar[Signal] = ... # positionOffsetChanged(float)
        positionScaleChanged     : typing.ClassVar[Signal] = ... # positionScaleChanged(float)
        recursiveChanged         : typing.ClassVar[Signal] = ... # recursiveChanged(bool)

        def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, activeAnimationGroup: int | None = ..., position: float | None = ..., positionScale: float | None = ..., positionOffset: float | None = ..., entity: PySide6.Qt3DCore.Qt3DCore.QEntity | None = ..., recursive: bool | None = ...) -> None: ...

        def activeAnimationGroup(self, /) -> int: ...
        def addAnimationGroup(self, animationGroups: PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationGroup, /) -> None: ...
        def animationGroupList(self, /) -> typing.List[PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationGroup]: ...
        def entity(self, /) -> PySide6.Qt3DCore.Qt3DCore.QEntity: ...
        def getAnimationIndex(self, name: str, /) -> int: ...
        def getGroup(self, index: int, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationGroup: ...
        def position(self, /) -> float: ...
        def positionOffset(self, /) -> float: ...
        def positionScale(self, /) -> float: ...
        def recursive(self, /) -> bool: ...
        def removeAnimationGroup(self, animationGroups: PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationGroup, /) -> None: ...
        def setActiveAnimationGroup(self, index: int, /) -> None: ...
        def setAnimationGroups(self, animationGroups: collections.abc.Sequence[PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationGroup], /) -> None: ...
        def setEntity(self, entity: PySide6.Qt3DCore.Qt3DCore.QEntity, /) -> None: ...
        def setPosition(self, position: float, /) -> None: ...
        def setPositionOffset(self, offset: float, /) -> None: ...
        def setPositionScale(self, scale: float, /) -> None: ...
        def setRecursive(self, recursive: bool, /) -> None: ...

    class QAnimationGroup(PySide6.QtCore.QObject):

        durationChanged          : typing.ClassVar[Signal] = ... # durationChanged(float)
        nameChanged              : typing.ClassVar[Signal] = ... # nameChanged(QString)
        positionChanged          : typing.ClassVar[Signal] = ... # positionChanged(float)

        def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, name: str | None = ..., position: float | None = ..., duration: float | None = ...) -> None: ...

        def addAnimation(self, animation: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimation, /) -> None: ...
        def animationList(self, /) -> typing.List[PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimation]: ...
        def duration(self, /) -> float: ...
        def name(self, /) -> str: ...
        def position(self, /) -> float: ...
        def removeAnimation(self, animation: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimation, /) -> None: ...
        def setAnimations(self, animations: collections.abc.Sequence[PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimation], /) -> None: ...
        def setName(self, name: str, /) -> None: ...
        def setPosition(self, position: float, /) -> None: ...

    class QBlendedClipAnimator(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipAnimator):

        blendTreeChanged         : typing.ClassVar[Signal] = ... # blendTreeChanged(QAbstractClipBlendNode*)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, blendTree: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode | None = ...) -> None: ...

        def blendTree(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode: ...
        def setBlendTree(self, blendTree: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode, /) -> None: ...

    class QCallbackMapping(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractChannelMapping):

        channelNameChanged       : typing.ClassVar[Signal] = ... # channelNameChanged(QString)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, channelName: str | None = ...) -> None: ...

        def callback(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationCallback: ...
        def channelName(self, /) -> str: ...
        def setCallback(self, type: int, callback: PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationCallback, /, flags: PySide6.Qt3DAnimation.Qt3DAnimation.QAnimationCallback.Flag = ...) -> None: ...
        def setChannelName(self, channelName: str, /) -> None: ...

    class QChannel(Shiboken.Object):

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, arg__1: PySide6.Qt3DAnimation.Qt3DAnimation.QChannel, /) -> None: ...
        @typing.overload
        def __init__(self, name: str, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...
        def appendChannelComponent(self, component: PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent, /) -> None: ...
        def begin(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent: ...
        def cbegin(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent: ...
        def cend(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent: ...
        def channelComponentCount(self, /) -> int: ...
        def clearChannelComponents(self, /) -> None: ...
        def end(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent: ...
        def insertChannelComponent(self, index: int, component: PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent, /) -> None: ...
        def jointIndex(self, /) -> int: ...
        def name(self, /) -> str: ...
        def removeChannelComponent(self, index: int, /) -> None: ...
        def setJointIndex(self, jointIndex: int, /) -> None: ...
        def setName(self, name: str, /) -> None: ...

    class QChannelComponent(Shiboken.Object):

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, arg__1: PySide6.Qt3DAnimation.Qt3DAnimation.QChannelComponent, /) -> None: ...
        @typing.overload
        def __init__(self, name: str, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...
        def appendKeyFrame(self, kf: PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame, /) -> None: ...
        def begin(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame: ...
        def cbegin(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame: ...
        def cend(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame: ...
        def clearKeyFrames(self, /) -> None: ...
        def end(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame: ...
        def insertKeyFrame(self, index: int, kf: PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame, /) -> None: ...
        def keyFrameCount(self, /) -> int: ...
        def name(self, /) -> str: ...
        def removeKeyFrame(self, index: int, /) -> None: ...
        def setName(self, name: str, /) -> None: ...

    class QChannelMapper(PySide6.Qt3DCore.Qt3DCore.QNode):

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ...) -> None: ...

        def addMapping(self, mapping: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractChannelMapping, /) -> None: ...
        def mappings(self, /) -> typing.List[PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractChannelMapping]: ...
        def removeMapping(self, mapping: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractChannelMapping, /) -> None: ...

    class QChannelMapping(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractChannelMapping):

        channelNameChanged       : typing.ClassVar[Signal] = ... # channelNameChanged(QString)
        propertyChanged          : typing.ClassVar[Signal] = ... # propertyChanged(QString)
        targetChanged            : typing.ClassVar[Signal] = ... # targetChanged(Qt3DCore::QNode*)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, channelName: str | None = ..., target: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., property: str | None = ...) -> None: ...

        def channelName(self, /) -> str: ...
        def property(self, /) -> str: ...
        def setChannelName(self, channelName: str, /) -> None: ...
        def setProperty(self, property: str, /) -> None: ...
        def setTarget(self, target: PySide6.Qt3DCore.Qt3DCore.QNode, /) -> None: ...
        def target(self, /) -> PySide6.Qt3DCore.Qt3DCore.QNode: ...

    class QClipAnimator(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipAnimator):

        clipChanged              : typing.ClassVar[Signal] = ... # clipChanged(Qt3DAnimation::QAbstractAnimationClip*)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, clip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimationClip | None = ...) -> None: ...

        def clip(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimationClip: ...
        def setClip(self, clip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimationClip, /) -> None: ...

    class QClipBlendValue(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode):

        clipChanged              : typing.ClassVar[Signal] = ... # clipChanged(Qt3DAnimation::QAbstractAnimationClip*)

        @typing.overload
        def __init__(self, clip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimationClip, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ...) -> None: ...
        @typing.overload
        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, clip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimationClip | None = ...) -> None: ...

        def clip(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimationClip: ...
        def setClip(self, clip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimationClip, /) -> None: ...

    class QClock(PySide6.Qt3DCore.Qt3DCore.QNode):

        playbackRateChanged      : typing.ClassVar[Signal] = ... # playbackRateChanged(double)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, playbackRate: float | None = ...) -> None: ...

        def playbackRate(self, /) -> float: ...
        def setPlaybackRate(self, playbackRate: float, /) -> None: ...

    class QKeyFrame(Shiboken.Object):

        class InterpolationType(enum.Enum):

            ConstantInterpolation     = 0x0
            LinearInterpolation       = 0x1
            BezierInterpolation       = 0x2


        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, coords: PySide6.QtGui.QVector2D, /) -> None: ...
        @typing.overload
        def __init__(self, coords: PySide6.QtGui.QVector2D, lh: PySide6.QtGui.QVector2D, rh: PySide6.QtGui.QVector2D, /) -> None: ...

        def __eq__(self, rhs: PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame, /) -> bool: ...
        def __ne__(self, rhs: PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame, /) -> bool: ...
        def coordinates(self, /) -> PySide6.QtGui.QVector2D: ...
        def interpolationType(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.InterpolationType: ...
        def leftControlPoint(self, /) -> PySide6.QtGui.QVector2D: ...
        def rightControlPoint(self, /) -> PySide6.QtGui.QVector2D: ...
        def setCoordinates(self, coords: PySide6.QtGui.QVector2D, /) -> None: ...
        def setInterpolationType(self, interp: PySide6.Qt3DAnimation.Qt3DAnimation.QKeyFrame.InterpolationType, /) -> None: ...
        def setLeftControlPoint(self, lh: PySide6.QtGui.QVector2D, /) -> None: ...
        def setRightControlPoint(self, rh: PySide6.QtGui.QVector2D, /) -> None: ...

    class QKeyframeAnimation(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimation):

        easingChanged            : typing.ClassVar[Signal] = ... # easingChanged(QEasingCurve)
        endModeChanged           : typing.ClassVar[Signal] = ... # endModeChanged(QKeyframeAnimation::RepeatMode)
        framePositionsChanged    : typing.ClassVar[Signal] = ... # framePositionsChanged(QList<float>)
        startModeChanged         : typing.ClassVar[Signal] = ... # startModeChanged(QKeyframeAnimation::RepeatMode)
        targetChanged            : typing.ClassVar[Signal] = ... # targetChanged(Qt3DCore::QTransform*)
        targetNameChanged        : typing.ClassVar[Signal] = ... # targetNameChanged(QString)

        class RepeatMode(enum.Enum):

            None_                     = 0x0
            Constant                  = 0x1
            Repeat                    = 0x2


        def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, framePositions: collections.abc.Sequence[float] | None = ..., target: PySide6.Qt3DCore.Qt3DCore.QTransform | None = ..., easing: PySide6.QtCore.QEasingCurve | None = ..., targetName: str | None = ..., startMode: PySide6.Qt3DAnimation.Qt3DAnimation.QKeyframeAnimation.RepeatMode | None = ..., endMode: PySide6.Qt3DAnimation.Qt3DAnimation.QKeyframeAnimation.RepeatMode | None = ...) -> None: ...

        def addKeyframe(self, keyframe: PySide6.Qt3DCore.Qt3DCore.QTransform, /) -> None: ...
        def easing(self, /) -> PySide6.QtCore.QEasingCurve: ...
        def endMode(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QKeyframeAnimation.RepeatMode: ...
        def framePositions(self, /) -> typing.List[float]: ...
        def keyframeList(self, /) -> typing.List[PySide6.Qt3DCore.Qt3DCore.QTransform]: ...
        def removeKeyframe(self, keyframe: PySide6.Qt3DCore.Qt3DCore.QTransform, /) -> None: ...
        def setEasing(self, easing: PySide6.QtCore.QEasingCurve | PySide6.QtCore.QEasingCurve.Type, /) -> None: ...
        def setEndMode(self, mode: PySide6.Qt3DAnimation.Qt3DAnimation.QKeyframeAnimation.RepeatMode, /) -> None: ...
        def setFramePositions(self, positions: collections.abc.Sequence[float], /) -> None: ...
        def setKeyframes(self, keyframes: collections.abc.Sequence[PySide6.Qt3DCore.Qt3DCore.QTransform], /) -> None: ...
        def setStartMode(self, mode: PySide6.Qt3DAnimation.Qt3DAnimation.QKeyframeAnimation.RepeatMode, /) -> None: ...
        def setTarget(self, target: PySide6.Qt3DCore.Qt3DCore.QTransform, /) -> None: ...
        def setTargetName(self, name: str, /) -> None: ...
        def startMode(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QKeyframeAnimation.RepeatMode: ...
        def target(self, /) -> PySide6.Qt3DCore.Qt3DCore.QTransform: ...
        def targetName(self, /) -> str: ...

    class QLerpClipBlend(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode):

        blendFactorChanged       : typing.ClassVar[Signal] = ... # blendFactorChanged(float)
        endClipChanged           : typing.ClassVar[Signal] = ... # endClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)
        startClipChanged         : typing.ClassVar[Signal] = ... # startClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, startClip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode | None = ..., endClip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode | None = ..., blendFactor: float | None = ...) -> None: ...

        def blendFactor(self, /) -> float: ...
        def endClip(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode: ...
        def setBlendFactor(self, blendFactor: float, /) -> None: ...
        def setEndClip(self, endClip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode, /) -> None: ...
        def setStartClip(self, startClip: PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode, /) -> None: ...
        def startClip(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractClipBlendNode: ...

    class QMorphTarget(PySide6.QtCore.QObject):

        attributeNamesChanged    : typing.ClassVar[Signal] = ... # attributeNamesChanged(QStringList)

        def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, attributeNames: collections.abc.Sequence[str] | None = ...) -> None: ...

        def addAttribute(self, attribute: PySide6.Qt3DCore.Qt3DCore.QAttribute, /) -> None: ...
        def attributeList(self, /) -> typing.List[PySide6.Qt3DCore.Qt3DCore.QAttribute]: ...
        def attributeNames(self, /) -> typing.List[str]: ...
        @staticmethod
        def fromGeometry(geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, attributes: collections.abc.Sequence[str], /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QMorphTarget: ...
        def removeAttribute(self, attribute: PySide6.Qt3DCore.Qt3DCore.QAttribute, /) -> None: ...
        def setAttributes(self, attributes: collections.abc.Sequence[PySide6.Qt3DCore.Qt3DCore.QAttribute], /) -> None: ...

    class QMorphingAnimation(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimation):

        easingChanged            : typing.ClassVar[Signal] = ... # easingChanged(QEasingCurve)
        interpolatorChanged      : typing.ClassVar[Signal] = ... # interpolatorChanged(float)
        methodChanged            : typing.ClassVar[Signal] = ... # methodChanged(QMorphingAnimation::Method)
        targetChanged            : typing.ClassVar[Signal] = ... # targetChanged(Qt3DRender::QGeometryRenderer*)
        targetNameChanged        : typing.ClassVar[Signal] = ... # targetNameChanged(QString)
        targetPositionsChanged   : typing.ClassVar[Signal] = ... # targetPositionsChanged(QList<float>)

        class Method(enum.Enum):

            Normalized                = 0x0
            Relative                  = 0x1


        def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, targetPositions: collections.abc.Sequence[float] | None = ..., interpolator: float | None = ..., target: PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer | None = ..., targetName: str | None = ..., method: PySide6.Qt3DAnimation.Qt3DAnimation.QMorphingAnimation.Method | None = ..., easing: PySide6.QtCore.QEasingCurve | None = ...) -> None: ...

        def addMorphTarget(self, target: PySide6.Qt3DAnimation.Qt3DAnimation.QMorphTarget, /) -> None: ...
        def easing(self, /) -> PySide6.QtCore.QEasingCurve: ...
        def getWeights(self, positionIndex: int, /) -> typing.List[float]: ...
        def interpolator(self, /) -> float: ...
        def method(self, /) -> PySide6.Qt3DAnimation.Qt3DAnimation.QMorphingAnimation.Method: ...
        def morphTargetList(self, /) -> typing.List[PySide6.Qt3DAnimation.Qt3DAnimation.QMorphTarget]: ...
        def removeMorphTarget(self, target: PySide6.Qt3DAnimation.Qt3DAnimation.QMorphTarget, /) -> None: ...
        def setEasing(self, easing: PySide6.QtCore.QEasingCurve | PySide6.QtCore.QEasingCurve.Type, /) -> None: ...
        def setMethod(self, method: PySide6.Qt3DAnimation.Qt3DAnimation.QMorphingAnimation.Method, /) -> None: ...
        def setMorphTargets(self, targets: collections.abc.Sequence[PySide6.Qt3DAnimation.Qt3DAnimation.QMorphTarget], /) -> None: ...
        def setTarget(self, target: PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer, /) -> None: ...
        def setTargetName(self, name: str, /) -> None: ...
        def setTargetPositions(self, targetPositions: collections.abc.Sequence[float], /) -> None: ...
        def setWeights(self, positionIndex: int, weights: collections.abc.Sequence[float], /) -> None: ...
        def target(self, /) -> PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer: ...
        def targetName(self, /) -> str: ...
        def targetPositions(self, /) -> typing.List[float]: ...

    class QSkeletonMapping(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractChannelMapping):

        skeletonChanged          : typing.ClassVar[Signal] = ... # skeletonChanged(Qt3DCore::QAbstractSkeleton*)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, skeleton: PySide6.Qt3DCore.Qt3DCore.QAbstractSkeleton | None = ...) -> None: ...

        def setSkeleton(self, skeleton: PySide6.Qt3DCore.Qt3DCore.QAbstractSkeleton, /) -> None: ...
        def skeleton(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAbstractSkeleton: ...

    class QVertexBlendAnimation(PySide6.Qt3DAnimation.Qt3DAnimation.QAbstractAnimation):

        interpolatorChanged      : typing.ClassVar[Signal] = ... # interpolatorChanged(float)
        targetChanged            : typing.ClassVar[Signal] = ... # targetChanged(Qt3DRender::QGeometryRenderer*)
        targetNameChanged        : typing.ClassVar[Signal] = ... # targetNameChanged(QString)
        targetPositionsChanged   : typing.ClassVar[Signal] = ... # targetPositionsChanged(QList<float>)

        def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, targetPositions: collections.abc.Sequence[float] | None = ..., interpolator: float | None = ..., target: PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer | None = ..., targetName: str | None = ...) -> None: ...

        def addMorphTarget(self, target: PySide6.Qt3DAnimation.Qt3DAnimation.QMorphTarget, /) -> None: ...
        def interpolator(self, /) -> float: ...
        def morphTargetList(self, /) -> typing.List[PySide6.Qt3DAnimation.Qt3DAnimation.QMorphTarget]: ...
        def removeMorphTarget(self, target: PySide6.Qt3DAnimation.Qt3DAnimation.QMorphTarget, /) -> None: ...
        def setMorphTargets(self, targets: collections.abc.Sequence[PySide6.Qt3DAnimation.Qt3DAnimation.QMorphTarget], /) -> None: ...
        def setTarget(self, target: PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer, /) -> None: ...
        def setTargetName(self, name: str, /) -> None: ...
        def setTargetPositions(self, targetPositions: collections.abc.Sequence[float], /) -> None: ...
        def target(self, /) -> PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer: ...
        def targetName(self, /) -> str: ...
        def targetPositions(self, /) -> typing.List[float]: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2023 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
from __future__ import annotations

from . import events

from typing import Any, Callable

import asyncio
import contextvars
import enum


class QAsyncioFuture():
    """ https://docs.python.org/3/library/asyncio-future.html """

    # Declare that this class implements the Future protocol. The field must
    # exist and be boolean - True indicates 'await' or 'yield from', False
    # indicates 'yield'.
    _asyncio_future_blocking = False

    class FutureState(enum.Enum):
        PENDING = enum.auto()
        CANCELLED = enum.auto()
        DONE_WITH_RESULT = enum.auto()
        DONE_WITH_EXCEPTION = enum.auto()

    def __init__(self, *, loop: "events.QAsyncioEventLoop | None" = None,
                 context: contextvars.Context | None = None) -> None:
        self._loop: "events.QAsyncioEventLoop"
        if loop is None:
            self._loop = asyncio.events.get_event_loop()  # type: ignore[assignment]
        else:
            self._loop = loop
        self._context = context

        self._state = QAsyncioFuture.FutureState.PENDING
        self._result: Any = None
        self._exception: BaseException | None = None

        self._cancel_message: str | None = None

        # List of callbacks that are called when the future is done.
        self._callbacks: list[Callable] = list()

    def __await__(self):
        if not self.done():
            self._asyncio_future_blocking = True
            yield self
            if not self.done():
                raise RuntimeError("await was not used with a Future or Future-like object")
        return self.result()

    __iter__ = __await__

    def _schedule_callbacks(self, context: contextvars.Context | None = None):
        """ A future can optionally have callbacks that are called when the future is done. """
        for cb in self._callbacks:
            self._loop.call_soon(
                cb, self, context=context if context else self._context)

    def result(self) -> Any | Exception:
        if self._state == QAsyncioFuture.FutureState.DONE_WITH_RESULT:
            return self._result
        if self._state == QAsyncioFuture.FutureState.DONE_WITH_EXCEPTION and self._exception:
            raise self._exception
        if self._state == QAsyncioFuture.FutureState.CANCELLED:
            if self._cancel_message:
                raise asyncio.CancelledError(self._cancel_message)
            else:
                raise asyncio.CancelledError
        raise asyncio.InvalidStateError

    def set_result(self, result: Any) -> None:
        self._result = result
        self._state = QAsyncioFuture.FutureState.DONE_WITH_RESULT
        self._schedule_callbacks()

    def set_exception(self, exception: Exception) -> None:
        self._exception = exception
        self._state = QAsyncioFuture.FutureState.DONE_WITH_EXCEPTION
        self._schedule_callbacks()

    def done(self) -> bool:
        return self._state != QAsyncioFuture.FutureState.PENDING

    def cancelled(self) -> bool:
        return self._state == QAsyncioFuture.FutureState.CANCELLED

    def add_done_callback(self, cb: Callable, *,
                          context: contextvars.Context | None = None) -> None:
        if self.done():
            self._loop.call_soon(
                cb, self, context=context if context else self._context)
        else:
            self._callbacks.append(cb)

    def remove_done_callback(self, cb: Callable) -> int:
        original_len = len(self._callbacks)
        self._callbacks = [_cb for _cb in self._callbacks if _cb != cb]
        return original_len - len(self._callbacks)

    def cancel(self, msg: str | None = None) -> bool:
        if self.done():
            return False
        self._state = QAsyncioFuture.FutureState.CANCELLED
        self._cancel_message = msg
        self._schedule_callbacks()
        return True

    def exception(self) -> BaseException | None:
        if self._state == QAsyncioFuture.FutureState.CANCELLED:
            raise asyncio.CancelledError
        if self.done():
            return self._exception
        raise asyncio.InvalidStateError

    def get_loop(self) -> asyncio.AbstractEventLoop:
        return self._loop
